[all-commits] [llvm/llvm-project] a55b01: [SystemZ/[z/OS] Guard source-epoch related testcas...

Tony Varghese via All-commits all-commits at lists.llvm.org
Sun Jul 19 19:03:32 PDT 2026


  Branch: refs/heads/users/tonykuttai/bump-diag-size-frontend
  Home:   https://github.com/llvm/llvm-project
  Commit: a55b011dabf8e5761d9955f98aa1138a10bd1a8a
      https://github.com/llvm/llvm-project/commit/a55b011dabf8e5761d9955f98aa1138a10bd1a8a
  Author: Abhina Sree <Abhina.Sreeskantharajan at ibm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/test/CodeGen/SystemZ/systemz-module.flags.c

  Log Message:
  -----------
  [SystemZ/[z/OS] Guard source-epoch related testcase to 64-bit clang targets (#210341)

This patch guards the following testcase for 64-bit clang targets Clang :: CodeGen/SystemZ/systemz-module.flags.c


  Commit: d63bd842939f22fad4e29660d66b99a9bf94e4b4
      https://github.com/llvm/llvm-project/commit/d63bd842939f22fad4e29660d66b99a9bf94e4b4
  Author: Slava Zakharin <szakharin at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M flang/include/flang/Optimizer/Dialect/FIROps.td
    M flang/lib/Optimizer/CodeGen/CodeGen.cpp
    M flang/lib/Optimizer/Dialect/FIROps.cpp
    A flang/test/Fir/create-box-codegen.fir
    M flang/test/Fir/fir-ops.fir
    M flang/test/Fir/invalid.fir

  Log Message:
  -----------
  [flang] Added fir.create_box operation. (#210220)

This patch adds `fir.create_box` operation that allows
creating `!fir.box<>` values with arbitrary byte strides.
It can be used to recreate boxes describing non-contiguous
arrays from descriptor components (base_addr/lbs/extents/strides)
across offload regions.

This is just initial definition and code generation code.
The folders and passes producing this operation will be added
later.


  Commit: fd55bbd6022ccb8d854f580b56c39177e80c256e
      https://github.com/llvm/llvm-project/commit/fd55bbd6022ccb8d854f580b56c39177e80c256e
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M compiler-rt/test/profile/Linux/counter_promo_for.c
    M compiler-rt/test/profile/Linux/counter_promo_while.c

  Log Message:
  -----------
  [compiler-rt] Fix tests after #205331 (#210370)

New optimizations changed some compiler-rt tests. Update the test
expectations based on this.

Fixes #210355.


  Commit: 0b666f74f94fffc2bc3380365704bcb61f2767d2
      https://github.com/llvm/llvm-project/commit/0b666f74f94fffc2bc3380365704bcb61f2767d2
  Author: David Young <davidayoung at meta.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M utils/bazel/llvm-project-overlay/lldb/source/Plugins/BUILD.bazel
    M utils/bazel/llvm-project-overlay/lldb/source/Plugins/plugin_config.bzl

  Log Message:
  -----------
  Add missing BigArchive container plugin to lldb's bazel build (#210304)

Another missing plugin and its libraries in the LLDB bazel build. Based
this one on source/Plugins/ObjectContainer/Big-Archive/CMakeLists.txt
and its dependecies ( {}.cpp & {}.h)

waiting on CI to confirm bazel is correct as cannot build locally.

Can confirm this library will convert to BUCK internally at Meta and
build with buck2 where we do have in the default plugin list.

bazel rule assisted with: claude


  Commit: 53c048b3732610c8d2d65c1d41603de26eb6ac4e
      https://github.com/llvm/llvm-project/commit/53c048b3732610c8d2d65c1d41603de26eb6ac4e
  Author: Louis Dionne <ldionne.2 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libcxx/utils/ci/images/libcxx_release_runners.txt

  Log Message:
  -----------
  [libc++] Update release runners to the image that was used on main at the branch point (#210378)

This will allow retaining a stable image for CI throughout the whole
LLVM 23 release.


  Commit: a67eac3e141e1044dd98524a010e719b42f51f5e
      https://github.com/llvm/llvm-project/commit/a67eac3e141e1044dd98524a010e719b42f51f5e
  Author: Anshil Gandhi <95053726+gandhi56 at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/SOPInstructions.td

  Log Message:
  -----------
  [NFC][AMDGPU] Cleanup in SOPInstructions.td (#210367)

- Eliminate code which was accidentally merged during a merge-conflict
(https://github.com/llvm/llvm-project/pull/203155/changes#r3560059941)
- Remove comments as they are specific to usubsat.


  Commit: db1f902cd6a95c9b80136dfcbe8beb7a58290641
      https://github.com/llvm/llvm-project/commit/db1f902cd6a95c9b80136dfcbe8beb7a58290641
  Author: Mishal Shah <mishal_shah at apple.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M .ci/compute_projects.py
    M .ci/compute_projects_test.py
    M .github/workflows/premerge.yaml

  Log Message:
  -----------
  Add macOS premerge check workflow (#207435)

Added a premerge check workflow for macOS self-hosted runners to build
and test projects.


  Commit: f04bf4791ae6d56b822f9bca6eb82ce4adccb989
      https://github.com/llvm/llvm-project/commit/f04bf4791ae6d56b822f9bca6eb82ce4adccb989
  Author: Mikhail R. Gadelha <mikhail at igalia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/src/__support/File/linux/CMakeLists.txt
    M libc/src/__support/File/linux/dir.cpp
    M libc/src/__support/File/linux/file.cpp
    M libc/src/__support/OSUtil/linux/CMakeLists.txt
    M libc/src/__support/OSUtil/linux/auxv.h
    M libc/src/__support/threads/linux/CMakeLists.txt
    M libc/src/__support/threads/linux/thread.cpp
    M libc/src/sched/linux/CMakeLists.txt
    M libc/src/sched/linux/sched_getaffinity.cpp
    M libc/src/spawn/linux/CMakeLists.txt
    M libc/src/spawn/linux/posix_spawn.cpp
    M libc/src/stdio/linux/CMakeLists.txt
    M libc/src/stdio/linux/remove.cpp
    M libc/src/sys/ipc/linux/CMakeLists.txt
    M libc/src/sys/ipc/linux/ftok.cpp
    R libc/src/sys/ipc/linux/kernel_statx.h
    M libc/src/sys/mman/linux/CMakeLists.txt
    M libc/src/sys/mman/linux/shm_unlink.cpp
    M libc/src/sys/time/linux/CMakeLists.txt
    M libc/src/sys/time/linux/utimes.cpp
    M libc/startup/linux/x86_64/CMakeLists.txt
    M libc/startup/linux/x86_64/tls.cpp
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel

  Log Message:
  -----------
  [libc][NFC] Port raw syscall users to existing syscall_wrappers (#208039)

Several call sites still invoked syscall_impl directly (or carried
their own SYS_* fallback ladders) for syscalls that already have a
wrapper in src/__support/OSUtil/linux/syscall_wrappers.

This PR removes these syscalls in favor of the syscall_wrappers.


  Commit: 246c752ef1b6098a7aa222f02ca09db76e17cabe
      https://github.com/llvm/llvm-project/commit/246c752ef1b6098a7aa222f02ca09db76e17cabe
  Author: Jordan Rupprecht <rupprecht at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M utils/bazel/llvm-project-overlay/libc/test/src/sys/socket/BUILD.bazel

  Log Message:
  -----------
  [bazel][libc] Add layering deps (#210380)

Not sure why CI didn't catch it, but
c5837b469c6d6f35eb0822cd9ebd7c2aa7e2ab75 adds some targets that are
broken when layering checks are enabled.


  Commit: c42ce32264f94a8800f4250d7b716cca55f77df6
      https://github.com/llvm/llvm-project/commit/c42ce32264f94a8800f4250d7b716cca55f77df6
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    A compiler-rt/docs/ASanABI.md
    R compiler-rt/docs/ASanABI.rst
    A compiler-rt/docs/BuildingCompilerRT.md
    R compiler-rt/docs/BuildingCompilerRT.rst
    A compiler-rt/docs/TestingGuide.md
    R compiler-rt/docs/TestingGuide.rst
    M flang/docs/CMakeLists.txt
    A flang/docs/CommandGuide/index.md
    R flang/docs/CommandGuide/index.rst
    A libsycl/docs/CodingGuidelines.md
    R libsycl/docs/CodingGuidelines.rst
    A libsycl/docs/index.md
    R libsycl/docs/index.rst
    M libsycl/test/README.md
    A libunwind/docs/BuildingLibunwind.md
    R libunwind/docs/BuildingLibunwind.rst
    M libunwind/docs/conf.py
    A libunwind/docs/index.md
    R libunwind/docs/index.rst
    M lldb/source/Plugins/TraceExporter/common/TraceHTR.h
    A lldb/source/Plugins/TraceExporter/docs/htr.md
    R lldb/source/Plugins/TraceExporter/docs/htr.rst
    A llvm-libgcc/docs/LLVMLibgcc.md
    R llvm-libgcc/docs/LLVMLibgcc.rst
    M llvm-libgcc/generate_version_script.py
    M offload/docs/conf.py
    A offload/docs/index.md
    R offload/docs/index.rst

  Log Message:
  -----------
  [docs] Rename misc rst docs to md (#210208)

Tracking issue: #201242
See the [migration guide] for more information. 

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines

This is the initial straight rename commit.

Many of these miscellaneous .rst files are not actually part of a real
docs build, since docs/conf.py does not exist for many of them.


  Commit: 9b096bb7abf7b57182ae8556451aa34dacd535ec
      https://github.com/llvm/llvm-project/commit/9b096bb7abf7b57182ae8556451aa34dacd535ec
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/bindings/interfaces.swig
    M lldb/include/lldb/API/LLDB.h
    M lldb/include/lldb/API/SBDefines.h
    A lldb/include/lldb/API/SBProtocolServer.h
    M lldb/source/API/CMakeLists.txt
    A lldb/source/API/SBProtocolServer.cpp
    M lldb/unittests/API/CMakeLists.txt
    A lldb/unittests/API/SBProtocolServerTest.cpp

  Log Message:
  -----------
  [lldb] Add SBProtocolServer to start protocol servers programmatically (#209923)

Starting a protocol server (such as MCP, and in the future potentially
DAP) is only possible from the command line today, via `protocol-server
start`. Add an SB API so an embedder can start one in its own process
and learn where to connect.

SBProtocolServer wraps ProtocolServer::GetOrCreate/Start/Stop and
exposes the listening connection URI. This lets a tool host the engine's
protocol server in-process and talk to it as a normal client, reusing
the server's tools rather than reimplementing them.

Assisted-by: Claude


  Commit: 2b6e9d261433f5ec8c49502f91d63dd7d07346c3
      https://github.com/llvm/llvm-project/commit/2b6e9d261433f5ec8c49502f91d63dd7d07346c3
  Author: Artem Belevich <tra at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/NVPTX/NVPTXISelLowering.cpp
    M llvm/test/CodeGen/NVPTX/atomicrmw-allow-ftz-atomics.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-sm60.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-sm70.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-sm90.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw.py
    M llvm/test/CodeGen/NVPTX/atomics.ll

  Log Message:
  -----------
  [NVPTX] Set default value of nvptx-allow-ftz-atomics to true (#206154)

This is a follow-up to https://github.com/llvm/llvm-project/pull/200732.

Setting the default value of nvptx-allow-ftz-atomics to true preserves
the status quo. It allows the NVPTX backend to emit native
floating-point atomic add instructions by default, rather than falling
back to the CAS loop required for strict FTZ compliance.

Correct FTZ handling forces a lot of existing code to emit CAS loops.
This introduces thread divergence, breaking code that relies on atomic
operations being non-divergent (for example, warp-wide atomic additions
followed by a load of the reduced value without explicit
synchronization).

While FTZ-correct atomic behavior is desirable as a long-term default,
introducing thread divergence into a common operation that previously
"happened to work" without synchronization is highly disruptive.
Defaulting to true makes the FTZ-correct behavior opt-in for now,
allowing users time to audit and adapt their code.

Test cases are updated to verify both enabled and disabled states of the
option, alongside the new default behavior.


  Commit: 50c8f07e3eebf1ff5a1d9378d77aef5df9583293
      https://github.com/llvm/llvm-project/commit/50c8f07e3eebf1ff5a1d9378d77aef5df9583293
  Author: Endre Fülöp <endre.fulop at sigmatechnology.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp
    A clang/test/Analysis/std-c-library-functions-non-integral-ssize_t.cpp

  Log Message:
  -----------
  [clang][analyzer] Fix assertion failure in StdLibraryFunctionsChecker with non-integral ssize_t (#209655)

In StdLibraryFunctionsCheckers' `RangeConstraint::checkSpecificValidity`
asserted that the constrained argument type is integral. When user code
typedefs `ssize_t` to a non-integral type (e.g. `float`) even though
this violates POSIX.1-2017, which requires `ssize_t` to be a signed
integer type, the signature still matches (same canonical type) and the
assertion fires during constraint validation. Remove it and let
`validateByConstraints` gracefully reject the summary by returning
false.

Fixes #209436


  Commit: 40c4fea67f49b841bd064624219efceab91b65e0
      https://github.com/llvm/llvm-project/commit/40c4fea67f49b841bd064624219efceab91b65e0
  Author: Krisitan Erik Olsen <kristian.erik at outlook.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Utils/SSAUpdater.cpp
    A llvm/test/Transforms/SROA/sroa-self-referential-load.ll

  Log Message:
  -----------
  [SROA] Fix assertion failure when promoting self-referential load/store (#208826)

When LoadAndStorePromoter::run processes a block where a store's value
operand is defined by the load being promoted (a self-referential cycle
in unreachable code), it sets StoredValue to the load instruction. When
it then calls replaceAllUsesWith, the doRAUW assertion fires because the
replacement value contains the value being replaced.

The single-block promotion paths in promoteSingleBlockAlloca already
guard against this with a check for ReplVal == LI, replacing with poison
instead. This patch adds the same guard to the in-block load path in
LoadAndStorePromoter::run, which was missing it. Substituting poison is
correct here since this situation only arises in unreachable code.

The regression was introduced in #135609, which added the
propagateStoredValuesToLoads path in SROA that routes through
LoadAndStorePromoter::run. LoadStoreRewriter handles aggregates and is
unrelated to this path.

Fixes #204799


  Commit: 714d124d0aaf3effa3e83d01783fe0ed2cd3eea9
      https://github.com/llvm/llvm-project/commit/714d124d0aaf3effa3e83d01783fe0ed2cd3eea9
  Author: Hongyu Chen <xxs_chy at outlook.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M cross-project-tests/intrinsic-header-tests/riscv_packed_simd.c

  Log Message:
  -----------
  Revert "[RISCV][P-ext][NFC] Add cross-project tests for packed zip/unzip intrinsics" (#210401)

Reverts llvm/llvm-project#209575


  Commit: 93b1240309309d5c2f8f94527ff7c7bd5df359af
      https://github.com/llvm/llvm-project/commit/93b1240309309d5c2f8f94527ff7c7bd5df359af
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M compiler-rt/docs/ASanABI.md
    M compiler-rt/docs/BuildingCompilerRT.md
    M compiler-rt/docs/TestingGuide.md
    M flang/docs/CommandGuide/index.md
    M libsycl/docs/CodingGuidelines.md
    M libsycl/docs/index.md
    M libunwind/docs/BuildingLibunwind.md
    M libunwind/docs/index.md
    M lldb/source/Plugins/TraceExporter/docs/htr.md
    M llvm-libgcc/docs/LLVMLibgcc.md
    M offload/docs/conf.py
    M offload/docs/index.md

  Log Message:
  -----------
  [docs] Finish misc MyST migration (#210209)

Tracking issue: #201242
See the [migration guide] for more information.

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines

This is a stacked PR based on #210208, which is the standalone rename
commit for this miscellaneous Markdown migration batch.

This was prepared with rst2myst plus LLM-assisted cleanup. LLDB man
pages are intentionally left as reStructuredText because LLDB man-page
building should not take on Markdown parser dependencies.

Unfortunately, many of these miscellaneous docs do not have working
standalone doc build targets, so I was not able to render HTML for all
of them. I think the scope is small enough that this is reviewable by
hand.


  Commit: 91bb8f4ee8452d3e2bda7544556fa66dba462414
      https://github.com/llvm/llvm-project/commit/91bb8f4ee8452d3e2bda7544556fa66dba462414
  Author: Ramkumar Ramachandra <artagnon at tenstorrent.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/VPlan.h
    M llvm/lib/Transforms/Vectorize/VPlanRecipes.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUnroll.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.h
    M llvm/test/Transforms/LoopVectorize/VPlan/RISCV/expand-scev.ll
    M llvm/test/Transforms/LoopVectorize/VPlan/dissolve-replicate-regions.ll

  Log Message:
  -----------
  [VPlan] Introduce vputils::doesGeneratePerAllLanes (#199047)

Introduce a query for recipes that produce scalar values for all VF
lanes, returning true for non-single-scalar replicates, non-first-lane
SIVSteps, and a couple of VPInstructions.


  Commit: 93bce300db95e4fbb82b1a6ef69fe125c71b77f3
      https://github.com/llvm/llvm-project/commit/93bce300db95e4fbb82b1a6ef69fe125c71b77f3
  Author: Ayokunle Amodu <ayokunle321 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx1250.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn.hip

  Log Message:
  -----------
  [CIR][AMDGPU] Add support for AMDGCN log builtins (#198032)

Adds codegen support for the following AMDGCN log builtins:

- __builtin_amdgcn_logf (float)
- __builtin_amdgcn_log_bf16 (bfloat16)

These are lowered to the corresponding `llvm.amdgcn.log` intrinsic.


  Commit: 3e55f3c56e8706fa12792b5a4de05f636bf798d0
      https://github.com/llvm/llvm-project/commit/3e55f3c56e8706fa12792b5a4de05f636bf798d0
  Author: Jackson Stogel <jtstogel at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/test/UnitTest/HermeticTestUtils.cpp
    M libc/test/src/stdlib/CMakeLists.txt
    M libc/test/src/stdlib/realpath_test.cpp

  Log Message:
  -----------
  [libc][realpath][test] Create test files/directories (#209369)

Follow-up PRs will add path validation etc to `realpath`, which will
require paths to exist in the filesystem.

This PR bumps the memory limit in `HermeticTestUtils.cpp`. The realpath
unit tests allocate quite a few strings, and since memory in hermetic
tests is never freed, the unit test quickly reaches the limit.


  Commit: 4070621c866fb4156f7c7d15039d12a4295f46c2
      https://github.com/llvm/llvm-project/commit/4070621c866fb4156f7c7d15039d12a4295f46c2
  Author: Slava Zakharin <szakharin at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M flang/lib/Optimizer/OpenACC/Support/FIROpenACCOpsInterfaces.cpp
    M flang/lib/Optimizer/OpenACC/Support/RegisterOpenACCExtensions.cpp
    A flang/test/Transforms/OpenACC/acc-implicit-declare-type-descriptor-create-box.fir

  Log Message:
  -----------
  [flang][OpenACC] Discover type descriptors referenced by fir.create_box (#210393)

Register the IndirectGlobalAccess interface for fir.create_box so
acc-implicit-declare finds the derived-type type-descriptor global a
create_box of a record array needs on the device, as it already does
for fir.embox and fir.rebox.

Assisted-by: Cursor


  Commit: 5c719eeb715632b1afef6508bd6c5ac09369fc91
      https://github.com/llvm/llvm-project/commit/5c719eeb715632b1afef6508bd6c5ac09369fc91
  Author: Amr Hesham <amr96 at programmer.net>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    M clang/lib/CIR/CodeGen/CIRGenBuiltin.cpp
    M clang/test/CIR/CodeGen/builtins-x86.c
    M clang/test/CIR/CodeGenBuiltins/builtins-elementwise.c

  Log Message:
  -----------
  [CIR] Implement support for builtin FMA (#210365)

Implement support for the _builtin_fma


  Commit: 95cc83d45b1b8e4a560efb729bd7e1e16f0b8703
      https://github.com/llvm/llvm-project/commit/95cc83d45b1b8e4a560efb729bd7e1e16f0b8703
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    A llvm/docs/AdminTasks.md
    R llvm/docs/AdminTasks.rst

  Log Message:
  -----------
  [docs] Rename AdminTasks to markdown to preserve history (#210415)

Tracking issue: #201242

Migrating this before I make changes to it. A follow-up PR will do the
migration.


  Commit: fb0547315ecf3f09fb6fc9122e40ff096a643eaa
      https://github.com/llvm/llvm-project/commit/fb0547315ecf3f09fb6fc9122e40ff096a643eaa
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/docs/AdminTasks.md

  Log Message:
  -----------
  [docs] Rewrite AdminTasks.md as markdown (#210416)

Tracking issue: #201242
This is a stacked PR based on #210415 , which does a rename for history
preservation purposes. See the [migration guide] for more information.

[migration guide]:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines

This was prepared with rst2myst.


  Commit: d982e0499b7f780279c435403b8249d7c3812cae
      https://github.com/llvm/llvm-project/commit/d982e0499b7f780279c435403b8249d7c3812cae
  Author: Diego Novillo <dnovillo at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/test/CodeGenHLSL/resources/TypedBuffers-constructor.hlsl

  Log Message:
  -----------
  [HLSL] Enable frontend IR generation for SPIR-V in TypedBuffers-constructor.hlsl (#207421)

I found a stale `FIXME` marker while poking at SPIR-V resource lowering.

The test stated that SPIR-V codegen of
`llvm.spv.resource.handlefrombinding` and resource types was not
implemented. That codegen now exists in
`CommonSPIRTargetCodeGenInfo::getHLSLType`.

This change enables the test on SPIR-V and splits the tests to
distinguish DXIL and SPIRV expected IR patterns.


  Commit: 9bae0aab8098f99dff47578546eb5bd382f919d0
      https://github.com/llvm/llvm-project/commit/9bae0aab8098f99dff47578546eb5bd382f919d0
  Author: LU-JOHN <John.Lu at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPUISelLowering.cpp
    M llvm/test/CodeGen/AMDGPU/div-rem-fast-path.ll
    M llvm/test/CodeGen/AMDGPU/med3-knownbits.ll
    M llvm/test/CodeGen/AMDGPU/sdiv.ll
    M llvm/test/CodeGen/AMDGPU/udiv.ll

  Log Message:
  -----------
  [AMDGPU] Remove unnecessary and broken sign/zero extension in fastdiv (#210348)

Remove unnecessary and broken sign/zero-extension when using float-point
reciprocal to implement division/remainder. This change is analogous to
the change done in https://github.com/llvm/llvm-project/pull/203436 but
in AMDGPUISelLowering.cpp.

Signed-off-by: John Lu <John.Lu at amd.com>


  Commit: dc3b1ed3ccd10995b26fa5278cb80c45419f9457
      https://github.com/llvm/llvm-project/commit/dc3b1ed3ccd10995b26fa5278cb80c45419f9457
  Author: Matt Arsenault <Matthew.Arsenault at amd.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    A llvm/test/TableGen/RuntimeLibcallEmitter-predicate-cc-sort.td
    M llvm/utils/TableGen/Basic/RuntimeLibcallsEmitter.cpp

  Log Message:
  -----------
  TableGen: Deterministically order predicate groups by calling convention (#210409)


  Commit: 6ff0ebea015e3ed984dfff941e7d8a48e4810784
      https://github.com/llvm/llvm-project/commit/6ff0ebea015e3ed984dfff941e7d8a48e4810784
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/include/lldb/Core/Diagnostics.h
    M lldb/source/Core/CoreProperties.td
    M lldb/source/Core/Debugger.cpp
    M lldb/source/Core/Diagnostics.cpp
    A lldb/test/Shell/Diagnostics/TestDiagnosticsCollectBinaries.test

  Log Message:
  -----------
  [lldb] Collect the executable, symbol file, and core in diagnostics (#210391)

The diagnostics bundle already gathers logs, statistics, and a snapshot
of the first triage commands, but sometimes the binaries are required to
reproduce an issue. Collect the main executable, its symbol file, and
the core file into the bundle.

Gate this on a new global setting, diagnostics.collect-binaries, which
defaults to false: these files can be large and privacy sensitive, so
including them is opt-in.

Assisted-by: Claude


  Commit: 977eced054d9de031423dee9493addd4e1fd5eaf
      https://github.com/llvm/llvm-project/commit/977eced054d9de031423dee9493addd4e1fd5eaf
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/source/Expression/IRInterpreter.cpp

  Log Message:
  -----------
  [lldb] Truncate an over-wide symbol address in the IR interpreter (#210372)

IRInterpreter::ResolveConstantValue built a pointer-width APInt directly
from the address returned by FindSymbol. That address can be wider than
a target pointer, because lldb records extra information in the high
bits on some targets, such as the code/memory address-space tag on
WebAssembly.

A 32-bit pointer then cannot hold the tagged address and the APInt
constructor asserts, aborting the debugger when a function-valued
expression is evaluated (for example `expr main`).

Truncate to the pointer width instead of asserting, matching the idiom
already used in DWARFExpression. On targets whose addresses fit in a
pointer this is a no-op.


  Commit: 4e0dbfe489dcc0b057303047608cd2a909602a14
      https://github.com/llvm/llvm-project/commit/4e0dbfe489dcc0b057303047608cd2a909602a14
  Author: Aleksandr Popov <42888396+aleks-tmb at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/test/Analysis/ScalarEvolution/max-backedge-taken-count-guard-info.ll

  Log Message:
  -----------
  [SCEV][NFC] Precommit test for MatchRangeCheckIdiom tightening (#210386)


  Commit: 0e3852f73ab75639b76bad2c8a735d46241768f3
      https://github.com/llvm/llvm-project/commit/0e3852f73ab75639b76bad2c8a735d46241768f3
  Author: Patryk Stefanski <patryk.stefanski at protonmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/Sema/SemaDecl.cpp
    M clang/test/Parser/cxx1z-decomposition.cpp

  Log Message:
  -----------
  [clang][sema] Fix crash on decomposition decl missing initializer (#210151)

ActOnUninitializedDecl dereferenced the std::optional<Token> from
Lexer::findNextToken() unconditionally when diagnosing a structured
binding with no initializer. Guard the optional and fall back to the
declaration's location.


  Commit: 82134c708f7ec224d86e2096d9b53c76640a490f
      https://github.com/llvm/llvm-project/commit/82134c708f7ec224d86e2096d9b53c76640a490f
  Author: Akshay K <iit.akshay at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenExpr.cpp
    M clang/lib/CIR/CodeGen/CIRGenExprAggregate.cpp
    M clang/test/CIR/CodeGen/ternary-throw.cpp

  Log Message:
  -----------
  [CIR] Terminate conditional regions after creation; fix glvalue conditional with a throw arm (#210384)

Follow-up to #208850: @andykaylor's comments about
`CIRGenFunction::emitConditionalBlocks` also have a similar
insertion-point problem.

The PR addresses the two related problems found while looking into the
conditional branch emission path:

**1. Terminate conditional regions after creation instead of patching
yields**
`CIRGenFunction::emitConditionalBlocks` still had the save-and-patch
insertion-point machinery removed from the scalar path in #208850. The
path is unreachable, and its guard is saved only after
`cir.unreachable`, where a patched yield would generate the dead code.
The machinery is removed; regions are closed with
`terminateStructuredRegionBody` after creation.

The aggregate emitter had the reverse problem: an unconditional
cir.yield after each arm lands in the dead block a throw leaves behind
and keeps it in the final CIR:

```
struct test_s { int x; int y; };
void test_throw(bool flag) {
  test_s a = flag ? throw 0 : test_s{1, 2};
}
mlir
cir.if %2 {
  ...
  cir.throw %3 : !cir.ptr<!s32i>, @_ZTIi
  cir.unreachable
^bb1:  // no predecessors      <-- dead block kept alive by the yield
  cir.yield
} else {
  ...
}
```
The explicit yields are removed; `emitIfOnBoolExpr` already terminates
each region, adding a yield only where one is missing. Tests pin the
dead block's absence with CIR-NEXT after `cir.unreachable`.

**2. Fix glvalue conditionals with a throw arm using a region-local
pointer**

```
int &ref_cond(bool c, int &x) { return c ? x : throw 0; }
// error: operand #0 does not dominate this use
// fatal error: CIR module verification error
```
With one arm throwing, `emitConditionalOperatorLValue` returned the
surviving arm's LValue directly, valid in OG CodeGen's flat CFG, invalid
in CIR where the pointer is materialized inside the ternary's region:

```
%4 = cir.ternary(%3, true {
  %8 = cir.load %1 ...          // pointer loaded inside the region
  cir.yield %8 : !cir.ptr<!s32i>
}, false { ... cir.unreachable })
cir.store %8, %2 ...            // region-local %8 used outside the region
```

Existing tests missed it because a local's pointer is a function-entry
`alloca`, so dominance held by accident. The fix addresses the result
through the ternary's result value, which the yield carries out. New
tests cover a reference parameter, assignment via the conditional, and
member access, all of which previously failed verification.

Assisted-by: Cursor/Codex


  Commit: ea863cb2dec8e0f040dfe22a52d3b537e4a25c29
      https://github.com/llvm/llvm-project/commit/ea863cb2dec8e0f040dfe22a52d3b537e4a25c29
  Author: Arthur Eubanks <aeubanks at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/CodeGen/SelectionDAG/DAGCombiner.cpp
    A llvm/test/CodeGen/X86/dagcombine-sub-globaladdress.ll

  Log Message:
  -----------
  [DAGCombiner] Fix APInt truncation assertion (#209914)

getConstant() would create an APInt with ImplicitTrunc = false, but the
constant here can really be anything.

Fixes #209884.


  Commit: 1e37b629fbd06d922ac1216cf20114ea4ce1c88d
      https://github.com/llvm/llvm-project/commit/1e37b629fbd06d922ac1216cf20114ea4ce1c88d
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libcxx/utils/libcxx/test/format.py
    M llvm/utils/lit/lit/TestRunner.py
    M llvm/utils/lit/lit/formats/shtest.py

  Log Message:
  -----------
  [lit] Delete the external shell (#209571)

This was deprecated in LLVM 23 and slated for removal in LLVM 24. Now
that we have branched and everything has been updated to not set
execute_external, we can remove it.


  Commit: 466503dcf2ae2e43126c1a6d8a5b204883d5b0c1
      https://github.com/llvm/llvm-project/commit/466503dcf2ae2e43126c1a6d8a5b204883d5b0c1
  Author: Logan <143111092+Logans-olo at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86InstrTBM.td
    M llvm/test/CodeGen/X86/tbm_patterns.ll

  Log Message:
  -----------
  X86: Add pattern for optimized BLSIC IR form (#209814)

Add DAG pattern to recognize the optimized IR form of BLSIC: (xor (and
x, -x), -1)

Fixes #209718 - matches the IR form produced after InstCombine
optimizations

Added tests for both 32-bit and 64-bit BLSIC patterns

Assisted by: Claude Code, helped me understand
pattern-matching/intrinsics, and some file structure. As well as how
testing for LLVM works.


  Commit: f97dcd05eb4be690dcfd39de9f6de937d5acfa46
      https://github.com/llvm/llvm-project/commit/f97dcd05eb4be690dcfd39de9f6de937d5acfa46
  Author: stephenduong1004 <stephenduong at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/tools/llvm-libtool-darwin/llvm-libtool-darwin.cpp

  Log Message:
  -----------
  [llvm-libtool-darwin] Ensure filelist buffer is null-terminated (#205115)

[llvm-libtool-darwin] Ensure filelist buffer is null-terminated

In llvm-libtool-darwin.cpp, `MemoryBuffer::getFileOrSTDIN` was
previously called to load the filelist with `RequiresNullTerminator` set
to `false`. However, the retrieved buffer is subsequently passed to
`llvm::line_iterator`.

Since `llvm::line_iterator` explicitly requires its underlying buffer to
be null-terminated, omitting this requirement can result in an
out-of-bounds read/buffer overrun when parsing the file list.

This change fixes the issue by requesting a null-terminated buffer
(`RequiresNullTerminator=true`).

Co-authored-by: Alexander Shaposhnikov <ashaposhnikov at google.com>


  Commit: 986cdd8618e3e105bde1d52e7d8888325a7c87b1
      https://github.com/llvm/llvm-project/commit/986cdd8618e3e105bde1d52e7d8888325a7c87b1
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/CMakeLists.txt
    A llvm/lib/Transforms/Vectorize/VPlanEVLTailFolding.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.h

  Log Message:
  -----------
  [VPlan] Move EVL-based transforms to VPlanEVLTransforms.cpp (NFC) (#209883)

VPlanTransforms.cpp has become quite big and is one of the top 20 most
expensive files in terms of compile-time.


https://llvm-compile-time-tracker.com/compare_clang.php?from=b8ba3c2b72cb53268129bbecfeb4ba7ec5b8d831&to=96a722a0ace661626d071166635728def97f6820&stat=instructions%3Au

Split off the mostly self-contained EVL related transforms and move them
to a new VPlanEVLTransforms.cpp.

This moves simplifyKnownEVL, optimizeEVLMasks, addExplicitVectorLength,
convertToVariableLengthStep and convertEVLExitCond together with their
EVL-specific static helpers.

Shared helpers used by the moved code (isDeadRecipe,
collectUsersRecursively, recursivelyDeleteDeadRecipes,
getOpcodeOrIntrinsicID and tryToFoldLiveIns, pullOutPermutations) are
promoted to vputils.

PR: https://github.com/llvm/llvm-project/pull/209883


  Commit: a12cbbcc94a80f54714aaa253f8838fcc9ab4aae
      https://github.com/llvm/llvm-project/commit/a12cbbcc94a80f54714aaa253f8838fcc9ab4aae
  Author: Jan Korous <jkorous at apple.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/ScalableStaticAnalysis/BuiltinAnchorSources.def
    M clang/lib/ScalableStaticAnalysis/Analyses/CMakeLists.txt
    A clang/lib/ScalableStaticAnalysis/Analyses/SharedLexicalRepresentation/EntitySourceLocationExtractor.cpp
    A clang/unittests/ScalableStaticAnalysis/Analyses/SharedLexicalRepresentation/EntitySourceLocationExtractorTest.cpp
    M clang/unittests/ScalableStaticAnalysis/CMakeLists.txt

  Log Message:
  -----------
  [SSAF] Add EntitySourceLocationExtractor (#210201)

Walks every entity-producing decl in the TU and emits
SourceLocationRecord(s) per entity-kind anchor:

* Identifier-bearing decls (FunctionDecl/VarDecl/FieldDecl/ RecordDecl):
Decl::getLocation().
* Synthetic function return-slot entity:
FD->getReturnTypeSourceRange().getBegin().
* ParmVarDecl (named or unnamed): P->getTypeSpecStartLoc().

Skips compiler-synthesized implicits and builtins via the getEntityName
gate, system-header decls via SourceManager, and silently drops records
whose location is invalid or whose file path cannot be canonicalized via
real_path.

Assisted-By: Claude Opus 4.7


  Commit: 284c1a166af4c7deab55c7de2ee1bd480d44e9ff
      https://github.com/llvm/llvm-project/commit/284c1a166af4c7deab55c7de2ee1bd480d44e9ff
  Author: David Mentler <mentlerd at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/docs/use/variable.md
    M lldb/include/lldb/API/SBValue.h
    M lldb/include/lldb/DataFormatters/TypeSynthetic.h
    M lldb/include/lldb/ValueObject/ValueObject.h
    M lldb/include/lldb/ValueObject/ValueObjectSynthetic.h
    M lldb/source/API/SBValue.cpp
    M lldb/source/DataFormatters/TypeSynthetic.cpp
    M lldb/source/ValueObject/ValueObject.cpp
    M lldb/source/ValueObject/ValueObjectSynthetic.cpp
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/Makefile
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/TestSBValueSetTypeSynthetic.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/library_support.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/main.cpp
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/Makefile
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/TestSBValueSetTypeSyntheticOverride.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/foo_bar_synths.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/main.cpp

  Log Message:
  -----------
  [LLDB] Enable SBTypeSynthetic manipulation for SBValue instances (#209056)

Allow manipulating the scripted synthetic children frontend selection
process for individual `SBValue` instances.

The motivating use-case is supporting custom data structures, type
erasure systems, and facilitating debugging handle based C APIs. Below
is an example of such a use-case of an anonymized 3rd party C library:
```C
using ErrorCode = int;
using Handle = void*;

using FooHandle = Handle;
using BarHandle = Handle;

struct ArrayOfHandles {
  int size;
  Handle* data;
};

struct AllHandles {
  ArrayOfHandles foos; 
  ArrayOfHandles bars;
};

ErrorCode GetAllHandles(AllHandles* into);
```

The current LLDB feature-set allows attaching a synthetic children
provider to `AllHandles`, but the scripted frontend has no chance to
select an appropriate alternative frontend implementation class for
`foos` and `bars` based on type information it is aware of.


  Commit: 9eb2dc0930ac75494e71b16739c859fe338a3f0f
      https://github.com/llvm/llvm-project/commit/9eb2dc0930ac75494e71b16739c859fe338a3f0f
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libcxx/utils/libcxx/test/format.py
    M llvm/utils/lit/lit/TestRunner.py
    M llvm/utils/lit/lit/formats/shtest.py

  Log Message:
  -----------
  Revert "[lit] Delete the external shell" (#210433)

Reverts llvm/llvm-project#209571

Breaks some buildbots:
1.
https://lab.llvm.org/buildbot/#/builders/232/builds/3690/steps/11/logs/stdio
2. https://lab.llvm.org/buildbot/#/builders/222/builds/11180


  Commit: 965fa410dad7294cc1c1a9632ff94558de6dfa40
      https://github.com/llvm/llvm-project/commit/965fa410dad7294cc1c1a9632ff94558de6dfa40
  Author: Sharjeel Khan <sharjeelkhan at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/MCTargetDesc/AArch64MCLFIRewriter.cpp
    A llvm/test/MC/AArch64/LFI/debug-info.s

  Log Message:
  -----------
  [LFI][AArch64] Fix Segfault due to infinite recursion in LFI rewriter (#210267)

When emitting a deferred LR guard, if debug info is enabled, the
emission of the guard instruction can trigger temporary labels (e.g. for
DWARF line entries), which recursively calls onLabel. Since
DeferredLRGuard was only set to false after emission, the nested call
would re-emit the guard, causing infinite recursion which leads to a
SegFault due to stack overflow. This was detected compiling
ubsan_minimal_handlers.cpp in compiler-rt. I fixed it by using the
existing recursion guard (Guard).


  Commit: 2120490a54645f9a4390605adec5509243641d29
      https://github.com/llvm/llvm-project/commit/2120490a54645f9a4390605adec5509243641d29
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/include/lldb/Core/Diagnostics.h
    M lldb/source/Core/Diagnostics.cpp
    M lldb/unittests/Core/CMakeLists.txt
    A lldb/unittests/Core/DiagnosticsTest.cpp

  Log Message:
  -----------
  [lldb] Add an artifact provider mechanism to Diagnostics (#210417)

Add a hook that lets a subsystem contribute a file to the diagnostics
bundle, without breaking layering and making Core depend on it. A plugin
registers an ArtifactProvider callback and a file name via AddArtifactProvider.
Providers run when a bundle is collected, and each one that yields
content is written into the bundle and recorded in the report's
attachments.

This restores, in a simpler form, the collection point that the removed
Diagnostics callback mechanism offered. The motivating consumer is the
downstream Swift health check, which registers a provider to write its
"swift-healthcheck.log" into the bundle. Unlike the old callback, a
provider does not open or write its own file: it just returns the
contents as a string and Diagnostics handles the rest.


  Commit: d592aa5a10f44164cd403257270802eb2a4b123a
      https://github.com/llvm/llvm-project/commit/d592aa5a10f44164cd403257270802eb2a4b123a
  Author: Tony Guillot <tony.guillot at protonmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/Parse/ParseDecl.cpp
    A clang/test/CXX/dcl/dcl.spec/dcl.type/dcl.type.general/p2.cpp

  Log Message:
  -----------
  [Clang] Fixed auto parsing regression with brace initialization (#210347)

The PR #208552 has introduced a regression where brace initialization
was not taken into account `auto foo{12}`. It was also breaking
`dcl.type.general` p2 rules, which is also now tested.


  Commit: 32221d9ff8f4772972193ebf7b8ba4974cd8458f
      https://github.com/llvm/llvm-project/commit/32221d9ff8f4772972193ebf7b8ba4974cd8458f
  Author: David Green <david.green at arm.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-gather.ll
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-scatter.ll

  Log Message:
  -----------
  [AArch64] Add lowering for fixed-vector bf16 masked gather/scatter. (#210273)

Similar to #208744, this makes sure that bf16 masked gather and scatter
work with fixed-length sve enabled. Without +bf16 the operations are
currently expanded pre-isel, but that will not be fixed in this patch as
it is a larger change and this patch is intended to be ported to the
branch.


  Commit: b4a444ad635af70fe32f58d46fe0c08221fbcf5a
      https://github.com/llvm/llvm-project/commit/b4a444ad635af70fe32f58d46fe0c08221fbcf5a
  Author: Jackson Stogel <jtstogel at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/src/stdlib/linux/CMakeLists.txt
    M libc/src/stdlib/linux/realpath.cpp
    M libc/test/src/stdlib/CMakeLists.txt
    M libc/test/src/stdlib/realpath_test.cpp

  Log Message:
  -----------
  [libc][realpath] Support relative paths (#209374)

Updates realpath to call the `getcwd` linux syscall wrapper to resolve
cwd-relative queries.


  Commit: 35bf12351740521f86fd406d01165e1c90b32ed8
      https://github.com/llvm/llvm-project/commit/35bf12351740521f86fd406d01165e1c90b32ed8
  Author: Razvan Lupusoru <razvan.lupusoru at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M mlir/include/mlir/Dialect/OpenACC/OpenACCCGOps.td
    M mlir/lib/Dialect/OpenACC/Transforms/ACCRecipeMaterialization.cpp
    M mlir/test/Dialect/OpenACC/ops-cg.mlir

  Log Message:
  -----------
  [mlir][acc] Preserve section bounds on acc.reduction_init (#210443)

When `acc.reduction_init` is created from `acc.reduction`, its bounds
are lost because they only live as values folded into the init region's
body. Those bounds describe the legal indexing of the section: the
produced view of a (possibly base-adjusted, compact) reduction temporary
must be indexed with the same bounds as the original array.

Carry the acc.bounds as optional operands on acc.reduction_init so this
indexing information is directly available. The operands are optional,
so scalar/whole-array reductions and existing IR are unaffected.


  Commit: 2b68eb4d70072d4e0084c0b4113bbd209c600088
      https://github.com/llvm/llvm-project/commit/2b68eb4d70072d4e0084c0b4113bbd209c600088
  Author: Aleksandr Popov <42888396+aleks-tmb at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Analysis/ScalarEvolution.cpp

  Log Message:
  -----------
  [SCEV][NFCI] Refactor LoopGuards range check matching (#210362)

Parameterize MatchRangeCheckIdiom over (Predicate, LHS, RHS) so it can
be reused for other predicates discovered during guard collection.

Hoist AddRewrite / GetMaybeRewritten above it and use them in place of
the inline try_emplace, so range-check rewrites chain onto existing ones
the same way other rewrites do.


  Commit: 2dbcd7d10f9462bdc30a169730919fc7da321905
      https://github.com/llvm/llvm-project/commit/2dbcd7d10f9462bdc30a169730919fc7da321905
  Author: adams381 <adams at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/CIR/Dialect/IR/CIRTypes.h
    M clang/include/clang/CIR/Dialect/Passes.h
    M clang/include/clang/CIR/Dialect/Passes.td
    M clang/lib/CIR/Dialect/IR/CIRTypes.cpp
    M clang/lib/CIR/Dialect/Transforms/CMakeLists.txt
    M clang/lib/CIR/Dialect/Transforms/CallConvLoweringPass.cpp
    M clang/lib/CIR/Dialect/Transforms/PassDetail.h
    A clang/test/CIR/Transforms/abi-lowering/x86_64-lang-addrspace-nyi.cir
    A clang/test/CIR/Transforms/abi-lowering/x86_64-scalars.cir
    M clang/unittests/CIR/CMakeLists.txt
    A clang/unittests/CIR/GetFloatingPointTypeTest.cpp

  Log Message:
  -----------
  [CIR] Add x86_64 scalar calling-convention lowering (#209636)

CallConvLowering can already classify a function through the MLIR test
target or through a classification injected as an attribute, but it has
no
path to a real target ABI. This adds a `target=x86_64` mode that runs
the
LLVM ABI Lowering Library's System V x86_64 classifier: it maps CIR
types to
`llvm::abi` types, calls the classifier, and converts the result back
into
the `mlir::abi::FunctionClassification` that `CIRABIRewriteContext`
already
consumes.

To keep the first step small this handles scalar signatures only --
integer
up to 64 bits, pointer, bool, `f32`, and `f64`.  Anything else (records,
arrays, vectors, `_Complex`, wide or uncommon floats, `_BitInt`,
`__int128`,
member pointers) is reported as not-yet-implemented through
`emitOpError`, so
an unsupported signature fails the pass instead of being silently
misclassified. Those types come in stacked follow-ups. The pass is still
only reachable from `cir-opt`; wiring it into the `-fclangir` pipeline
is a
later change.

Assisted-by: Cursor / claude-opus-4.8


  Commit: 12e3d9db0088d95675a0081495122483faa7b60d
      https://github.com/llvm/llvm-project/commit/12e3d9db0088d95675a0081495122483faa7b60d
  Author: Akshay K <iit.akshay at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltin.cpp
    M clang/test/CIR/CodeGen/var_arg.c

  Log Message:
  -----------
  [CIR] Add support for lowering __builtin_c23_va_start in ClangIR (#208741)

C23 `va_start `expands to `__builtin_c23_va_start`, which was previously
routed to the unimplemented-builtin NYI path in ClangIR. As a result,
variadic code failed to compile with -fclangir in -std=c23 mode.

This change lowers `__builtin_c23_va_start` the same way as
`__builtin_va_start`. For both builtins, the va_list operand is always
argument 0, so the existing lowering logic can be reused directly.


  Commit: fefdf74c073b0361fb9a5100f6b1f38a13d72e55
      https://github.com/llvm/llvm-project/commit/fefdf74c073b0361fb9a5100f6b1f38a13d72e55
  Author: lianjinfeng2003 <101249452+mygitljf at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
    A llvm/test/CodeGen/RISCV/rvv/vecreduce-minmax-constant-fold.ll

  Log Message:
  -----------
  [SelectionDAG] Fold constant min/max vector reductions (#209190)

I extended constant folding to handle signed and unsigned min/max vector
reductions. Constant vectors now become scalar constants before target
lowering, while non-constant, poison, and undef behavior stays
unchanged.
Fixes #209109


  Commit: 2926d18a0620a768857dce1c827d0a3da0d0b565
      https://github.com/llvm/llvm-project/commit/2926d18a0620a768857dce1c827d0a3da0d0b565
  Author: Pengxiang Huang <71998072+Pengxiang-Huang at users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M libc/src/semaphore/linux/CMakeLists.txt
    M libc/src/semaphore/linux/named_semaphore.cpp
    M libc/src/semaphore/linux/semaphore.h
    M libc/test/src/semaphore/linux/CMakeLists.txt
    M libc/test/src/semaphore/linux/semaphore_test.cpp

  Log Message:
  -----------
  [libc][semaphore] Add post and wait operations for internal semaphore (#198959)

This pr implements https://github.com/llvm/llvm-project/issues/190847,
adding the post and wait operations in posix semaphore for linux using
futex.

Particularly, 
`sem_post`:
https://pubs.opengroup.org/onlinepubs/9799919799/functions/sem_post.html
`sem_trywait`, `sem_wait`:
https://pubs.opengroup.org/onlinepubs/9799919799/functions/sem_wait.html
`sem_timedwait`, `sem_clockwait`:
https://pubs.opengroup.org/onlinepubs/9799919799/functions/sem_clockwait.html#

The implementation is assisted by Claude Code Opus 4.7, specifically for
the unit tests generations.


  Commit: c1c278e7484038f1d14314f38736532975fafd20
      https://github.com/llvm/llvm-project/commit/c1c278e7484038f1d14314f38736532975fafd20
  Author: Jan Korous <jkorous at apple.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    A clang/docs/ScalableStaticAnalysis/user-docs/SourceEditGeneration.rst
    M clang/include/clang/Basic/DiagnosticFrontendKinds.td
    M clang/include/clang/Basic/DiagnosticIDs.h
    M clang/include/clang/Frontend/SSAFOptions.h
    M clang/include/clang/Options/Options.td
    A clang/include/clang/ScalableStaticAnalysis/Frontend/SourceTransformationFrontendAction.h
    M clang/lib/Driver/ToolChains/Clang.cpp
    M clang/lib/FrontendTool/ExecuteCompilerInvocation.cpp
    M clang/lib/ScalableStaticAnalysis/Frontend/CMakeLists.txt
    A clang/lib/ScalableStaticAnalysis/Frontend/SourceTransformationFrontendAction.cpp
    M clang/test/Analysis/Scalable/help.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/Inputs/empty-suite.json
    A clang/test/Analysis/Scalable/source-edit-generation/Inputs/two-function-suite.json
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/CMakeLists.txt
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/TestTransformationPlugin/CMakeLists.txt
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/TestTransformationPlugin/TestTransformation.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/lit.local.cfg
    A clang/test/Analysis/Scalable/source-edit-generation/cli-errors.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/coexistence.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/downgradable-errors.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/happy-path.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/write-failure.cpp
    M clang/test/CMakeLists.txt

  Log Message:
  -----------
  [clang][ssaf] Integrate source-edit-generation (#208590)

Adds the four `--ssaf-*` driver flags
(`--ssaf-source-transformation=`,
`--ssaf-global-scope-analysis-result=`, `--ssaf-src-edit-file=`,
`--ssaf-transformation-report-file=`) under `SSAF_Group`, marshalled
into `FrontendOptions`. The compilation-unit identifier flag introduced
earlier is reused. The driver forwards all four flags to `cc1`.

Adds twelve `warn_ssaf_*` diagnostics under
`-Wscalable-static-analysis-framework` (`DefaultError`) covering the
orphan-flag matrix, unknown transformation names, unknown output
formats, WPA-suite read failures, and edit/report write failures.

Adds `clang::ssaf::SourceTransformationFrontendAction` — a
`WrapperFrontendAction` that, when any source-edit flag is set,
validates the CLI as a group, loads the WPASuite from the configured
path, instantiates the named transformation, and serializes the
accumulated edits and findings through the configured formats. The
action is wrapped in `ExecuteCompilerInvocation` after the existing
TU-summary wrap so both pipelines stack as independent `ASTConsumer`s on
the same translation unit; they exchange no data.

Assisted-By: Claude Opus 4.7


  Commit: 372cd15f03e49bb826a63a6c59cc7f74962ab278
      https://github.com/llvm/llvm-project/commit/372cd15f03e49bb826a63a6c59cc7f74962ab278
  Author: Valentin Clement (バレンタイン クレメン) <clementval at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M flang/include/flang/Optimizer/OpenACC/Support/FIROpenACCOpsInterfaces.h
    M flang/lib/Optimizer/OpenACC/Support/FIROpenACCOpsInterfaces.cpp
    M mlir/include/mlir/Dialect/OpenACC/OpenACCOpsInterfaces.td
    M mlir/lib/Dialect/OpenACC/IR/OpenACC.cpp
    M mlir/lib/Dialect/OpenACC/Transforms/ACCImplicitDeclare.cpp
    M mlir/test/Dialect/OpenACC/acc-implicit-declare.mlir

  Log Message:
  -----------
  [openacc] Implicitly map external constant globals (#210408)

Hoist initializer-less constant globals out of OpenACC compute regions
so implicit data mapping handles them. This avoids unresolved device
symbols for PARAMETER arrays defined in separately compiled modules,
while retaining implicit declare for initialized constants. Add
regression coverage and a global initializer query to the OpenACC
interface.


  Commit: 3fbb037d03e7ff1ef1cd9156363e895af7caaf98
      https://github.com/llvm/llvm-project/commit/3fbb037d03e7ff1ef1cd9156363e895af7caaf98
  Author: Haowei <haowei at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/cmake/modules/ClangConfig.cmake.in
    M compiler-rt/cmake/Modules/CompilerRTUtils.cmake
    M llvm/cmake/modules/LLVMConfig.cmake.in
    M runtimes/CMakeLists.txt

  Log Message:
  -----------
  Adding an option to Skip LLVM and Clang exports (#209922)

Under CMake 4+, calling add_library(... SHARED IMPORTED) on a
target platform that lacks dynamic linking support triggers a fatal
error. This becomes an issue when building LLVM and runtimes for
baremetal targets like armv6m-none-eabi. This patch
adds the option "LLVM_OMIT_EXPORTS_FROM_CONFIG" in LLVM.
When used in sub builds like LLVM runtimes, it makes CMake to skip
including the LLVM and Clang exports. This mitigates the CMake 4
errors on baremetal runtimes.


  Commit: dbab04510ee89e5e9ed03cb6aff63fd218fb3042
      https://github.com/llvm/llvm-project/commit/dbab04510ee89e5e9ed03cb6aff63fd218fb3042
  Author: Teresa Johnson <tejohnson at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/TailRecursionElimination.cpp
    A llvm/test/Transforms/TailCallElim/disable-tail-call-elim-for-cold-calls.ll

  Log Message:
  -----------
  [TailCallElim] Optionally suppress tail call elim for cold calls (#209642)

Since eliminated tail calls result in missing frames when collecting
various types of profiles, provide an option for disabling the
elimination for cold non-musttail calls. By default the new handling is
disabled.

Since the new checks require BFI to be built in more cases, I have moved
UpdateFunctionEntryCount and ForceDisableBFI (renamed to
DisableEntryCountRecompute to match the flag and description), to
actually guard the function entry count update.


  Commit: c4962f5721a36e198234019b846d3788738f766a
      https://github.com/llvm/llvm-project/commit/c4962f5721a36e198234019b846d3788738f766a
  Author: Med Ismail Bennani <ismail at bennani.ma>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/include/lldb/Core/PluginManager.h
    M lldb/include/lldb/Interpreter/ScriptInterpreter.h
    M lldb/source/Commands/CommandObjectScripting.cpp
    M lldb/source/Commands/Options.td
    M lldb/source/Core/PluginManager.cpp
    M lldb/source/Interpreter/ScriptInterpreter.cpp
    M lldb/source/Interpreter/embedded_interpreter.py
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedPythonInterface.h
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPython.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPython.h
    A lldb/test/API/functionalities/scripting_extension_generate/Makefile
    A lldb/test/API/functionalities/scripting_extension_generate/TestScriptingExtensionGenerate.py
    A lldb/test/API/functionalities/scripting_extension_generate/main.c

  Log Message:
  -----------
  [lldb/script] Add scripting extension template generator (#209647)

This patch adds a `scripting extension generate <ExtensionType>...`
command that introspects a Python extension base class and emits a
skeleton subclass with `# TODO: Implement` stubs for its abstract
methods (or, with `-a`, every method), then opens the result in an
editor.

Generated imports use `from <module> import <class>`, and the generated
`__init__` forwards its arguments to `super().__init__(...)` since every
base class relies on its constructor to set up attributes
(`self.target`, `self.process`, ...) that inherited, non-overridden
methods depend on. When the host can't open an external editor (e.g.
non-macOS), the command reports that as a message rather than an error,
since the file is already written.

To catch regressions in the generator itself instead of just checking
that a file was produced, this patch adds
`TestScriptingExtensionGenerate.py`, which generates a template for
every extension kind on the fly and drives it through a live lldb
session (`process launch -C`, `breakpoint set -P`, `target stop-hook add
-P`, etc.).

Signed-off-by: Med Ismail Bennani <ismail at bennani.ma>


  Commit: ccd75bb4b9c6d9c2e149d355c35193ca554c99a0
      https://github.com/llvm/llvm-project/commit/ccd75bb4b9c6d9c2e149d355c35193ca554c99a0
  Author: Andy Kaylor <akaylor at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/include/clang/CIR/Dialect/Builder/CIRBaseBuilder.h
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    M clang/include/clang/CIR/Interfaces/CIRLoopOpInterface.td
    M clang/lib/CIR/Dialect/IR/CIRDialect.cpp
    M clang/lib/CIR/Interfaces/CIRLoopOpInterface.cpp
    A clang/test/CIR/IR/invalid-loop-cleanup.cir
    A clang/test/CIR/IR/loop-cleanup.cir
    M clang/unittests/CIR/ControlFlowTest.cpp

  Log Message:
  -----------
  [CIR] Introduce loop cleanup regions (#210212)

For loops and while loops can create variables in their condition
regions that require per-iteration cleanup. The CIR dialect previously
had no clean way to represent these cleanups while maintaining a
separate condition region for the loop operation.

This change introduces an optional cleanup region to these loop ops and
updates the relevant region successor handling to reflect the insertion
of the cleanup region in the control flow when a non-empty cleanup
region is present.

The CFG flattening pass will handle routing the control flow through the
cleanup region in both the normal and EH unwind cases, but this is not
yet implemented. That will be added in a follow-up change, as will
creation of the cleanup region when it is needed during IR generation.

Assisted-by: Cursor / various models


  Commit: ab6ef5680eb79e102414740198f5aa1015c5c254
      https://github.com/llvm/llvm-project/commit/ab6ef5680eb79e102414740198f5aa1015c5c254
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
    M lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.h
    M lldb/unittests/Process/gdb-remote/CMakeLists.txt
    A lldb/unittests/Process/gdb-remote/ProcessGDBRemoteTest.cpp

  Log Message:
  -----------
  [lldb] Contribute the GDB-remote packet history to diagnostics bundles (#210418)

Register a Diagnostics artifact provider from ProcessGDBRemote so a
diagnostics bundle captures the GDB-remote packet history, the same data
"process plugin packet history" prints.


  Commit: 03b9039147cca65e2b4fa3adcbbbf40f73e3a3c9
      https://github.com/llvm/llvm-project/commit/03b9039147cca65e2b4fa3adcbbbf40f73e3a3c9
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/docs/AdminTasks.md

  Log Message:
  -----------
  [docs] Update the commit review admin task with process details (#210420)

As discussed in the infra area team meeting. Mostly this serves as a
place to stash helpful links.

I picked an arbitrary two week timeout for requests. We can re-evaluate at any time.
It seems less than ideal that one needs issue tracker labelling
privileges to reopen the issue, but I think that's accurate.


  Commit: 42eb7db188f23625872b6f1d722979a3100d170e
      https://github.com/llvm/llvm-project/commit/42eb7db188f23625872b6f1d722979a3100d170e
  Author: Haowei <haowei at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/cmake/modules/ClangConfig.cmake.in
    M compiler-rt/cmake/Modules/CompilerRTUtils.cmake
    M llvm/cmake/modules/LLVMConfig.cmake.in
    M runtimes/CMakeLists.txt

  Log Message:
  -----------
  Revert "Skipping host target exports during cross-compilation" (#210468)

Reverts llvm/llvm-project#209922
It broke runtimes build on amdgpu-amd-amdhsa


  Commit: d00710093a3d2795200dbf065836220345aa9e9d
      https://github.com/llvm/llvm-project/commit/d00710093a3d2795200dbf065836220345aa9e9d
  Author: Igor Kudrin <ikudrin at accesssoftek.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M lldb/packages/Python/lldbsuite/test/tools/lldb-dap/dap_server.py

  Log Message:
  -----------
  [lldb-dap][test] Avoid a hang on a test failure (#209988)

Tests in `TestDAP_server.py` create `DebugAdapterServer`, passing a
connection string. `DebugAdapterServer.__init__()` creates a socket and
passes the associated input and output streams to its parent class,
`DebugCommunication`. `DAPTestCaseBase.launch()`, which is called from
`TestDAP_server.run_debug_session()`, adds a teardown hook that
eventually calls `DebugCommunication.terminate()`. If the socket is not
closed when this hook executes, it waits indefinitely for the receiving
thread to join.

In the normal case, when a test passes, the connection is closed by
calling `self.dap_server.request_disconnect()` at the end of
`TestDAP_server.run_debug_session()`. If a test fails, the cleanup hook
is called while the connection is still active, which results in a hang.
This can be reproduced by removing the call to `request_disconnect()` or
by changing the condition in the `assertEqual()` on the previous line.

The fix passes the opened socket to 'DebugCommunication' and closes the
socket explicitly in 'DebugCommunication.terminate()'.


  Commit: fb2fa0b0f0a8b061401f6cfa3c2fadd3fbfb3b35
      https://github.com/llvm/llvm-project/commit/fb2fa0b0f0a8b061401f6cfa3c2fadd3fbfb3b35
  Author: Lucas Ribeiro Lima <lucasribeirolima974 at gmail.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltinX86.cpp
    M clang/test/CIR/CodeGenBuiltins/X86/avx2-builtins.c
    M clang/test/CIR/CodeGenBuiltins/X86/avx512bw-builtins.c
    M clang/test/CIR/CodeGenBuiltins/X86/sse-builtins.c

  Log Message:
  -----------
  [clang][clangIR]: X86 upstream avx psrldqi/pslldqi (#208025)

This PR upstreams the implementation and corresponding test suites for
X86 byte-shift intrinsics (pslldqi / psrldqi) spanning 128, 256, and
512-bit vector variants from the incubator.

I consolidated both left and right shifts into a single code path since
the underlying lane topology is identical, extracting the
direction-specific index arithmetic into clean variables at the top. Let
me know if you prefer this unified data-driven approach or if explicit
split functions for left/right shifts would be preferred for local
readability.

All integrated tests from the incubator have been upstreamed and are
currently passing.

Minimal compile case
```cpp
#include <emmintrin.h>
#include <iostream>

struct DataLayout {
  alignas(16) int values[4];
};

#define INDEX 1

int main(int argc, char **argv) {
  DataLayout data{8, 4, 2, 1};

  std::cout << "Value before: " << data.values[INDEX] << '\n';

  __m128i reg128i =
      _mm_load_si128(reinterpret_cast<__m128i const *>(data.values));
  __m128i reg_right_shift = _mm_bsrli_si128(reg128i, 4);
  __m128i reg_left_shift = _mm_bslli_si128(reg128i, 4);

  DataLayout result_right;
  _mm_store_si128(reinterpret_cast<__m128i *>(result_right.values),
                  reg_right_shift);

  DataLayout result_left;
  _mm_store_si128(reinterpret_cast<__m128i *>(result_left.values),
                  reg_left_shift);

  std::cout << "Value after left: " << result_left.values[INDEX] << '\n';
  std::cout << "Value after right: " << result_right.values[INDEX] << '\n';

  return 0;
}
```
Addresses #167752.


  Commit: b0440cb55a22e979e81934e0c031c9d46e71f9da
      https://github.com/llvm/llvm-project/commit/b0440cb55a22e979e81934e0c031c9d46e71f9da
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericCycleImpl.h
    M llvm/include/llvm/ADT/GenericCycleInfo.h

  Log Message:
  -----------
  [CycleInfo] Reference cycles by preorder index, not pointer. NFC (#210271)

The block-to-innermost-cycle map (BlockMap) and each cycle's parent link
hold a GenericCycle pointer. Store the cycle's preorder index instead,
so no raw cycle pointer remains in the stored representation: BlockMap
becomes a SmallVector<unsigned>, four bytes per block rather than eight,
and the parent link becomes ParentIndex.

The flat Cycles array does not exist during construction, so both hold
creation-order indices into the temporary forest until flatten()
resolves them to preorder indices.

Aided by Claude Opus 4.8


  Commit: ee5d6f537da4bc81b956b4813afbc0877f82b59d
      https://github.com/llvm/llvm-project/commit/ee5d6f537da4bc81b956b4813afbc0877f82b59d
  Author: forking-google-bazel-bot[bot] <265904573+forking-google-bazel-bot[bot]@users.noreply.github.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M utils/bazel/llvm-project-overlay/clang/BUILD.bazel

  Log Message:
  -----------
  [Bazel] Fixes c1c278e (#210451)

This fixes c1c278e7484038f1d14314f38736532975fafd20.

Buildkite error link:
https://buildkite.com/llvm-project/upstream-bazel/builds?commit=c1c278e7484038f1d14314f38736532975fafd20

Co-authored-by: Google Bazel Bot <google-bazel-bot at google.com>


  Commit: 1ef8ba9a00e16423d711ddbf16c7a45fb7fd570b
      https://github.com/llvm/llvm-project/commit/1ef8ba9a00e16423d711ddbf16c7a45fb7fd570b
  Author: Luc Forget <github at alias.lforget.fr>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M mlir/lib/Target/Wasm/TranslateFromWasm.cpp

  Log Message:
  -----------
  [MLIR][WasmSSA] Instruction parser refactoring of WasmSSA importer (#195500)

Refactored WasmSSA importer mechanism to dispatch control flow to
relevant parser based on op code.
This is to prepare for instructions with multi-bytes opcodes (e.g.
vector instruction and some scalar instructions extensions) which will
be able to reuse the same mechanism.

It also replaces the bit tree to find the address by a jump table.

---------

Co-authored-by: Luc Forget <lforg37 at users.noreply.github.com>
Co-authored-by: Ferdinand Lemaire <ferdinand.lemaire at woven-planet.global>
Co-authored-by: Ferdinand Lemaire <flscminecraft at gmail.com>


  Commit: cf11eef1c9476c8778055d7963fdac34b6628582
      https://github.com/llvm/llvm-project/commit/cf11eef1c9476c8778055d7963fdac34b6628582
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    A llvm/docs/AArch64SME.md
    R llvm/docs/AArch64SME.rst
    A llvm/docs/AMDGPUAsyncOperations.md
    R llvm/docs/AMDGPUAsyncOperations.rst
    A llvm/docs/AMDGPUExecutionSynchronization.md
    R llvm/docs/AMDGPUExecutionSynchronization.rst
    A llvm/docs/AMDGPUMemoryModel.md
    R llvm/docs/AMDGPUMemoryModel.rst
    A llvm/docs/AddingConstrainedIntrinsics.md
    R llvm/docs/AddingConstrainedIntrinsics.rst
    A llvm/docs/BigEndianNEON.md
    R llvm/docs/BigEndianNEON.rst
    A llvm/docs/CompileCudaWithLLVM.md
    R llvm/docs/CompileCudaWithLLVM.rst
    A llvm/docs/DebuggingJITedCode.md
    R llvm/docs/DebuggingJITedCode.rst
    A llvm/docs/ExtendingLLVM.md
    R llvm/docs/ExtendingLLVM.rst
    A llvm/docs/HowToBuildWindowsItaniumPrograms.md
    R llvm/docs/HowToBuildWindowsItaniumPrograms.rst
    A llvm/docs/HowToCrossCompileBuiltinsOnArm.md
    R llvm/docs/HowToCrossCompileBuiltinsOnArm.rst
    A llvm/docs/HowToUpdateDebugInfo.md
    R llvm/docs/HowToUpdateDebugInfo.rst
    A llvm/docs/Instrumentor.md
    R llvm/docs/Instrumentor.rst
    A llvm/docs/JITLink.md
    R llvm/docs/JITLink.rst
    A llvm/docs/MCJITDesignAndImplementation.md
    R llvm/docs/MCJITDesignAndImplementation.rst
    A llvm/docs/NVPTXUsage.md
    R llvm/docs/NVPTXUsage.rst
    A llvm/docs/ORCv2.md
    R llvm/docs/ORCv2.rst
    A llvm/docs/Remarks.md
    R llvm/docs/Remarks.rst
    A llvm/docs/SPIRVUsage.md
    R llvm/docs/SPIRVUsage.rst

  Log Message:
  -----------
  [docs] Rename selected LLVM docs to Markdown (#208800)

Tracking issue: https://github.com/llvm/llvm-project/issues/201242
Migration guide docs:
https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines
RFC:
https://discourse.llvm.org/t/rfc-make-myst-markdown-the-llvm-docs-format-rip-rest/90840

This is the initial straight rename commit. It will probably break the
docs build, but it has to be a separate PR for blame preservation
purposes.


  Commit: cddf2069ded94cb47048ad2a5f340d12c35f1651
      https://github.com/llvm/llvm-project/commit/cddf2069ded94cb47048ad2a5f340d12c35f1651
  Author: Reid Kleckner <rkleckner at nvidia.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/docs/AArch64SME.md
    M llvm/docs/AMDGPUAsyncOperations.md
    M llvm/docs/AMDGPUExecutionSynchronization.md
    M llvm/docs/AMDGPUMemoryModel.md
    M llvm/docs/AddingConstrainedIntrinsics.md
    M llvm/docs/BigEndianNEON.md
    M llvm/docs/CompileCudaWithLLVM.md
    M llvm/docs/DebuggingJITedCode.md
    M llvm/docs/ExtendingLLVM.md
    M llvm/docs/HowToBuildWindowsItaniumPrograms.md
    M llvm/docs/HowToCrossCompileBuiltinsOnArm.md
    M llvm/docs/HowToUpdateDebugInfo.md
    M llvm/docs/Instrumentor.md
    M llvm/docs/JITLink.md
    M llvm/docs/MCJITDesignAndImplementation.md
    M llvm/docs/NVPTXUsage.md
    M llvm/docs/ORCv2.md
    M llvm/docs/Remarks.md
    M llvm/docs/SPIRVUsage.md

  Log Message:
  -----------
  [docs] Rewrite 19 LLVM docs from reST to markdown (#208798)

Tracking issue: #201242
[Migration
guide](https://llvm.org/docs/SphinxQuickstartTemplate.html#markdown-migration-guidelines)

This is a stacked PR based on #208800, which does the file rename to
preserve history.

This was prepared with rst2myst plus LLM-assisted cleanup. I paged
through all the generated HTML looking for migration artifacts, and all
of the differences I could find appear to be formatting error
corrections.


  Commit: a623e8d4381e26eceff29209e6db411617d95f83
      https://github.com/llvm/llvm-project/commit/a623e8d4381e26eceff29209e6db411617d95f83
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/utils/gn/secondary/clang/unittests/CIR/BUILD.gn

  Log Message:
  -----------
  [gn build] Port 2dbcd7d10f94 (#210484)


  Commit: 605b6d73214cf253fc5fb9d5befe99857bd480cf
      https://github.com/llvm/llvm-project/commit/605b6d73214cf253fc5fb9d5befe99857bd480cf
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/utils/gn/secondary/llvm/lib/Transforms/Vectorize/BUILD.gn

  Log Message:
  -----------
  [gn build] Port 986cdd8618e3 (#210485)


  Commit: 56fc7bf0c364ab210c49c3b95e7130d337490b78
      https://github.com/llvm/llvm-project/commit/56fc7bf0c364ab210c49c3b95e7130d337490b78
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/Frontend/BUILD.gn

  Log Message:
  -----------
  [gn build] Port c1c278e74840 (#210488)


  Commit: 2e1c934fea272654ab2b00f60b6d3dba93123190
      https://github.com/llvm/llvm-project/commit/2e1c934fea272654ab2b00f60b6d3dba93123190
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/Analyses/BUILD.gn
    M llvm/utils/gn/secondary/clang/unittests/ScalableStaticAnalysis/BUILD.gn

  Log Message:
  -----------
  [gn build] Port a12cbbcc94a8 (#210487)


  Commit: 3be5663001465e74c7b879ad4d4cbfc3c94caeba
      https://github.com/llvm/llvm-project/commit/3be5663001465e74c7b879ad4d4cbfc3c94caeba
  Author: Nico Weber <thakis at chromium.org>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/utils/gn/secondary/lldb/source/API/BUILD.gn

  Log Message:
  -----------
  [gn build] Port 9b096bb7abf7 (#210486)


  Commit: 6a33b69d8bae737e5e1d60c7b7776a0b1f885bfa
      https://github.com/llvm/llvm-project/commit/6a33b69d8bae737e5e1d60c7b7776a0b1f885bfa
  Author: Kazu Hirata <kazu at google.com>
  Date:   2026-07-17 (Fri, 17 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ProfileData/SampleProf.h
    M llvm/include/llvm/ProfileData/SampleProfReader.h
    M llvm/include/llvm/ProfileData/SampleProfWriter.h
    M llvm/lib/ProfileData/SampleProfReader.cpp
    M llvm/lib/ProfileData/SampleProfWriter.cpp
    M llvm/test/tools/llvm-profdata/profile-symbol-list.test
    M llvm/unittests/ProfileData/SampleProfTest.cpp

  Log Message:
  -----------
  [SampleProfile] Support MD5-based ProfileSymbolList (#210235)

This patch speeds up sample profile loading by introducing an
MD5-based ProfileSymbolList (cold symbol list) in extensible binary
profiles.

The sample profile loader spends about a third of its time on loading
and decoding the symbol names in the Profile Symbol List section, yet
we use them only for membership checking purposes via
ProfileSymbolList::contains.

This patch teaches the writer to emit the section as an array of
64-bit GUIDs in the Eytzinger layout.  The reader checks the
SecFlagMD5 section flag and sets up an EytzingerTableSpan
pointing into the mmap memory.  This achieves both space efficiency
and runtime efficiency.

The new flag, md5-prof-sym-list, is off by default for now.

Profile merging is supported only from strings to an MD5-based
Eytzinger array.

RFC:
https://discourse.llvm.org/t/rfc-faster-sample-profile-loading/90957/7

Assisted-by: Antitygravity


  Commit: ea50c8cc99778825fc647cf190d8f7a8f49cdcdd
      https://github.com/llvm/llvm-project/commit/ea50c8cc99778825fc647cf190d8f7a8f49cdcdd
  Author: Mishal Shah <mishal_shah at apple.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M .github/workflows/premerge.yaml

  Log Message:
  -----------
  Fix macOS casing in premerge workflow (#210477)


  Commit: 3fc4fcade6164fc6b9dcf0d6d0d6fa9cf6e47dfc
      https://github.com/llvm/llvm-project/commit/3fc4fcade6164fc6b9dcf0d6d0d6fa9cf6e47dfc
  Author: Ryosuke Niwa <rniwa at webkit.org>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M clang/lib/StaticAnalyzer/Checkers/WebKit/RawPtrRefCallArgsChecker.cpp
    M clang/test/Analysis/Checkers/WebKit/call-args.cpp

  Log Message:
  -----------
  [alpha.webkit.UncountedCallArgsChecker] Crash in printArgument (#210411)

The crash was caused by missing nullptr check for Decl used to get
printing policy. Fixed the bug by replacing the use of Decl with
BugManager to get the policy.


  Commit: 2730fc8a1a46ea92bbe91e3fc31897498617e076
      https://github.com/llvm/llvm-project/commit/2730fc8a1a46ea92bbe91e3fc31897498617e076
  Author: Arseniy Obolenskiy <arseniy.obolenskiy at amd.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Target/SPIRV/SPIRVInstructionSelector.cpp
    M llvm/test/CodeGen/SPIRV/extensions/SPV_KHR_bfloat16/bfloat16.ll

  Log Message:
  -----------
  [SPIR-V] Handle bfloat in getZeroFP/getOneFP (#202859)

Related spirv-val change:
https://github.com/KhronosGroup/SPIRV-Tools/pull/6734

---------

Co-authored-by: Juan Manuel Martinez Caamaño <jmartinezcaamao at gmail.com>


  Commit: ccd0e982a02fa3be39a98dd98ea6cc1ccaf24d13
      https://github.com/llvm/llvm-project/commit/ccd0e982a02fa3be39a98dd98ea6cc1ccaf24d13
  Author: Nerixyz <nerixdev at outlook.de>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M lldb/source/Plugins/SymbolFile/NativePDB/UdtRecordCompleter.cpp
    A lldb/test/API/lang/cpp/enum-limits/Makefile
    A lldb/test/API/lang/cpp/enum-limits/TestCPPEnumLimits.py
    A lldb/test/API/lang/cpp/enum-limits/main.cpp

  Log Message:
  -----------
  [lldb][NativePDB] Fix width and signedness of enum constants (#210338)

Enumerator values aren't always encoded in the correct bit width and
signedness. This happens with both MSVC and Clang.

On MSVC, unsigned 64bit enumerators can be encoded as signed. For
example `ULONGLONG_MAX` will be encoded as `-1`.
Clang/LLVM will always encode the values as unsigned.

Example: https://godbolt.org/z/96YjGW48W.

I fixed this by setting the expected width and signedness when creating
the enumerator constant. We can't use a shell test like for the other
PDB tests, because no output shows the enum values.


  Commit: 8c2d7cc3a9983459628c028d8537eaf79551f396
      https://github.com/llvm/llvm-project/commit/8c2d7cc3a9983459628c028d8537eaf79551f396
  Author: Jared Hoberock <jaredhoberock at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M mlir/include/mlir/IR/CMakeLists.txt
    M mlir/include/mlir/IR/SymbolInterfaces.td
    M mlir/include/mlir/IR/SymbolTable.h
    M mlir/lib/IR/SymbolTable.cpp
    A mlir/test/IR/test-verifiers-symbol-user-type.mlir
    M mlir/test/lib/Dialect/Test/TestTypeDefs.td
    M mlir/test/lib/Dialect/Test/TestTypes.cpp
    M mlir/test/lib/Dialect/Test/TestTypes.h
    M utils/bazel/llvm-project-overlay/mlir/BUILD.bazel

  Log Message:
  -----------
  [mlir][IR] Add SymbolUserTypeInterface (#198435)

This change adds SymbolUserTypeInterface, analogous to
SymbolUserAttrInterface, and extends SymbolTable verification to check
participating types.

Verification visits the types owned by an operation, (operand/result
types, block argument types, attribute-contained types, nested type
parameters) and checks each distinct type at most once, interrupting on
the first failure. Deduplication spans the whole symbol-table walk, so a
type used by multiple operations is checked only once.

Attribute (SymbolUserAttrInterface) verification also gets deduped the
same way.

Assisted-by: Codex (OpenAI)
Assisted-by: Claude (Anthropic)


  Commit: 1faa9f73119f007583ca829e07d78e82a40f1bae
      https://github.com/llvm/llvm-project/commit/1faa9f73119f007583ca829e07d78e82a40f1bae
  Author: Ramkumar Ramachandra <artagnon at tenstorrent.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/LoopVectorizationPlanner.h
    M llvm/lib/Transforms/Vectorize/VPlanEVLTailFolding.cpp
    M llvm/lib/Transforms/Vectorize/VPlanRecipes.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUnroll.cpp

  Log Message:
  -----------
  [VPlan] Infer SrcTy in createScalarExtOrTrunc (NFC) (#210423)

The argument is redundant and can be inferred from Op.


  Commit: d46a352ecf9708255a938e6d5e972b5221de4c2c
      https://github.com/llvm/llvm-project/commit/d46a352ecf9708255a938e6d5e972b5221de4c2c
  Author: David Mentler <mentlerd at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M lldb/test/API/python_api/sbvalue_set_type_synthetic_override/TestSBValueSetTypeSyntheticOverride.py

  Log Message:
  -----------
  [lldb] Fix TestSBValueSetTypeSyntheticOverride with libstdc++ (#210495)

My test added in #209056 assumed that a `CXXSyntheticChildren`
implementation for `std::vector` is readily available on all platforms,
that is not the case.

Do the simplest thing and remove this part of the test for now.

Fixes: https://lab.llvm.org/buildbot/#/builders/59/builds/35839
```
FAIL: test (TestSBValueSetTypeSyntheticOverride.TestCase)
----------------------------------------------------------------------
Traceback (most recent call last):
  File "/home/tcwg-buildbot/worker/lldb-aarch64-ubuntu/llvm-project/lldb/test/API/python_api/sbvalue_set_type_synthetic_override/TestSBValueSetTypeSyntheticOverride.py", line 22, in test
    self.checkOverride(vec, before=None)
  File "/home/tcwg-buildbot/worker/lldb-aarch64-ubuntu/llvm-project/lldb/test/API/python_api/sbvalue_set_type_synthetic_override/TestSBValueSetTypeSyntheticOverride.py", line 43, in checkOverride
    self.assertIsNone(impl_before)
AssertionError: <lldb.formatters.cpp.gnu_libstdcpp.StdVectorSynthProvider object at 0xfb088f787bb0> is not None
```


  Commit: e96755f08bab48f1578bd70a1f55d336b5e44a69
      https://github.com/llvm/llvm-project/commit/e96755f08bab48f1578bd70a1f55d336b5e44a69
  Author: Ramkumar Ramachandra <artagnon at tenstorrent.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/VPlan.h
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.h

  Log Message:
  -----------
  [VPlan] Factor vputils::getOpcodeOrIntrinsicID (NFC) (#208993)

The check for recipes in vputils::isElementWise is necessary to prevent
regressions.


  Commit: 1f4d6acc935f93eca55cfef67348c8abcc1415db
      https://github.com/llvm/llvm-project/commit/1f4d6acc935f93eca55cfef67348c8abcc1415db
  Author: pzoln <pashka.zolnikov at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M mlir/lib/Dialect/Bufferization/IR/BufferizationOps.cpp
    M mlir/test/Dialect/Bufferization/canonicalize.mlir

  Log Message:
  -----------
  [mlir][bufferization] Avoid invalid memref.cast in to_buffer folding (#208973)

Fixes #202782

When folding bufferization.to_buffer(bufferization.to_tensor(...)), only
create a memref.cast if the source and destination memref types are
cast-compatible.

This avoids asserting on unranked memrefs with different memory spaces
and leaves the original bufferization ops in place instead.

 Assisted-by: OpenAI Codex


  Commit: c69896aa8733ceed6e8cc982eec64b97f277f926
      https://github.com/llvm/llvm-project/commit/c69896aa8733ceed6e8cc982eec64b97f277f926
  Author: lonely eagle <2020382038 at qq.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M mlir/lib/Interfaces/ValueBoundsOpInterface.cpp

  Log Message:
  -----------
  [mlir][interface] Use populateAndCompare cleanup compare (NFC) (#200156)


  Commit: af0aa9440f1121bd5041a3dd7abef0d78b0f91cd
      https://github.com/llvm/llvm-project/commit/af0aa9440f1121bd5041a3dd7abef0d78b0f91cd
  Author: Anatoly Trosinenko <atrosinenko at accesssoftek.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AArch64/AArch64AsmPrinter.cpp
    M llvm/lib/Target/AArch64/AArch64InstrInfo.td
    M llvm/test/CodeGen/AArch64/ptrauth-intrinsic-auth-resign-with-blend.ll

  Log Message:
  -----------
  [AArch64][PAC] Rework the expansion of AUT/AUTPAC pseudos (#169699)

Refactor `AArch64AsmPrinter::emitPtrauthAuthResign` to improve
readability and tune the conditions when `emitPtrauthDiscriminator` is
allowed to clobber address discriminator operands.

When resigning, do not clobber address discriminator register used for
authentication if it is also used for signing. Such clobbering would
prevent passing raw, 64-bit value as the new discriminator. Clarify
other corner cases of clobbering address discriminator operands.

Reuse `enum PtrauthCheckMode` instead of separate `ShouldCheck` and
`ShouldTrap` flags and drop its `Default` enumerator.


  Commit: 0c5b2258f0b517c0822e5b2f8e6a8de311d6db9d
      https://github.com/llvm/llvm-project/commit/0c5b2258f0b517c0822e5b2f8e6a8de311d6db9d
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Analysis/ScalarEvolution.cpp
    M llvm/test/Transforms/IndVarSimplify/drop-exact.ll
    M llvm/test/Transforms/IndVarSimplify/pr66066.ll
    M llvm/test/Transforms/IndVarSimplify/strengthen-overflow.ll
    M llvm/test/Transforms/LoopVectorize/single-early-exit-deref-assumptions.ll

  Log Message:
  -----------
  [SCEV] Infer no-wrap flags for shl by a constant. (#208434)

Treat `shl %a, C` as `mul %a, 1 << C` in
getStrengthenedNoWrapFlagsFromBinOp
if possible.

Only transfer NSW from shl to mul, if the shift amount is < Bitwidth -
1, otherwise the result would be more poisonous.

Alive2 proofs: https://alive2.llvm.org/ce/z/iBPpkv

Compile-time impact in noise:
https://llvm-compile-time-tracker.com/compare.php?from=a037729976f91dc11b41a76834dfca9d8812c4fe&to=2050d622aed5606774f0902b352bbb2142e654e1&stat=instructions:u

PR: https://github.com/llvm/llvm-project/pull/208434


  Commit: d199b284c7d3f98bb7afbbca9e79e078a1da55fe
      https://github.com/llvm/llvm-project/commit/d199b284c7d3f98bb7afbbca9e79e078a1da55fe
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M orc-rt/docs/Design.md
    M orc-rt/include/orc-rt/Session.h
    M orc-rt/test/unit/SessionTest.cpp

  Log Message:
  -----------
  [orc-rt] Drop callManagedCodeAsync; tokens guard execution (#210508)

callManagedCodeSync is renamed to callManagedCode, and
callManagedCodeAsync is removed.

callManagedCodeAsync held a ManagedCodeTaskGroup token from the initial
call until the async continuation ran -- across the gap in which the
call is suspended and no managed code is executing. A token is meant to
guard managed code that is executing on a stack, so holding one across
that gap guards nothing while blocking shutdown.

callManagedCode holds a token only for the synchronous call to the
wrapped function, including anything the function runs inline on the
same thread before returning. An async function is called the same way,
with its continuation passed as an ordinary argument. Work deferred past
the function's return -- stashed, or handed to another thread -- runs on
a stack the token no longer guards; whoever later runs it is responsible
for ensuring a token covers it, acquiring one and aborting if the
acquire is denied.

See the new "Managed code execution and shutdown" section in
docs/Design.md for the full model (what a token guards, nested entries,
context-free acquire, and the abortability obligation).


  Commit: 7b446294e098c7c02bbc998da1b4a438f7270879
      https://github.com/llvm/llvm-project/commit/7b446294e098c7c02bbc998da1b4a438f7270879
  Author: Krzysztof Parzyszek <Krzysztof.Parzyszek at amd.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/include/llvm/Support/MathExtras.h
    M llvm/unittests/Support/MathExtrasTest.cpp

  Log Message:
  -----------
  [Support] Add constexpr versions of Add/Sub/MulOverflow (#210404)

<sub>Stack created with <a
href="https://github.com/github/gh-stack">GitHub Stacks CLI</a> • <a
href="https://gh.io/stacks-feedback">Give Feedback 💬</a></sub>


  Commit: 36c812f77142aa77b99b4e4d059ccba591a944c0
      https://github.com/llvm/llvm-project/commit/36c812f77142aa77b99b4e4d059ccba591a944c0
  Author: Krzysztof Parzyszek <Krzysztof.Parzyszek at amd.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/Sequence.h
    M llvm/unittests/ADT/SequenceTest.cpp

  Log Message:
  -----------
  [ADT] Make enum iterators constexpr (#210405)

<sub>Stack created with <a
href="https://github.com/github/gh-stack">GitHub Stacks CLI</a> • <a
href="https://gh.io/stacks-feedback">Give Feedback 💬</a></sub>


  Commit: fdf1adc8910ce4083d4c18205f665ef3c30cc851
      https://github.com/llvm/llvm-project/commit/fdf1adc8910ce4083d4c18205f665ef3c30cc851
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M orc-rt/include/orc-rt/Session.h

  Log Message:
  -----------
  [orc-rt] Add comment for Session::HandlerTag type. NFC. (#210510)


  Commit: af0c933eda31b6beb436026a22121ec637f3cb53
      https://github.com/llvm/llvm-project/commit/af0c933eda31b6beb436026a22121ec637f3cb53
  Author: Ramkumar Ramachandra <artagnon at tenstorrent.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M clang/lib/CodeGen/TargetInfo.cpp
    M clang/test/CodeGenOpenCL/cl20-device-side-enqueue-attributes.cl
    M llvm/docs/LangRef.md
    M llvm/include/llvm/IR/Function.h
    M llvm/lib/IR/Verifier.cpp
    M llvm/test/CodeGen/AArch64/is_fpclass.ll
    M llvm/test/CodeGen/AArch64/sms-loop-carried-fp-exceptions1.mir
    M llvm/test/CodeGen/AArch64/sve-streaming-mode-cvt-fp-to-int.ll
    M llvm/test/CodeGen/AArch64/sve-streaming-mode-cvt-int-to-fp.ll
    M llvm/test/CodeGen/PowerPC/milicode32.ll
    M llvm/test/CodeGen/PowerPC/ppcf128-constrained-fp-intrinsics.ll
    M llvm/test/CodeGen/RISCV/double-intrinsics-strict.ll
    M llvm/test/CodeGen/RISCV/float-intrinsics-strict.ll
    M llvm/test/CodeGen/RISCV/zfh-half-intrinsics-strict.ll
    M llvm/test/CodeGen/RISCV/zfhmin-half-intrinsics-strict.ll
    M llvm/test/CodeGen/SPIRV/llvm-intrinsics/constrained-fmuladd.ll
    M llvm/test/Transforms/EarlyCSE/replace-calls-def-attrs.ll
    M llvm/test/Transforms/InstCombine/erf.ll
    M llvm/test/Transforms/InstCombine/fdim.ll
    M llvm/test/Transforms/InstSimplify/disable_folding.ll
    M llvm/test/Transforms/SimplifyCFG/X86/merge-compatible-invokes-of-landingpad.ll
    M llvm/unittests/IR/VerifierTest.cpp
    M mlir/test/Target/LLVMIR/llvmir-intrinsics.mlir

  Log Message:
  -----------
  [IR] Make semantics of strictfp consistent (#209465)

Although the section on constrainedfp in the LangRef clearly states "All
function definitions that use constrained floating point intrinsics must
have the strictfp attribute", indicating that a function with strictfp
calls must be marked with strictfp, the general description of strictfp
does not specify this. Refine its semantics and make it so, eliminating
the inconsistency.


  Commit: 94b08b5de90dc21453a1dcde10cc1cd44ba93f7c
      https://github.com/llvm/llvm-project/commit/94b08b5de90dc21453a1dcde10cc1cd44ba93f7c
  Author: Alex Rønne Petersen <alex at alexrp.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Support/Unix/Signals.inc

  Log Message:
  -----------
  [Support] Improve the logic for re-raising signals (#177864)

On most systems, checking `si_pid` is not actually valid unless
`si_code` equals one of the relevant signal codes (`SI_USER`,
`SI_QUEUE`, and on some OSs, `SI_LWP`), or the signal is `SIGCHLD`. So
on e.g. NetBSD, we would misinterpret the `SIGSEGV` fault address as the
sending PID and incorrectly conclude that the signal came from a
different process.

But as far as I can tell, there's not even a valid reason for us to be
checking `si_pid != getpid()`, because the signal could very well have
been explicitly sent by another thread in the current process. So we
really just need to check `si_code` for the aforementioned signal codes.

Darwin is the exception because it just doesn't set `si_code` at all in
the case of the `SI_*` signal codes. So keep the old logic there, even
though it misses the corner case of signals sent by a thread in the
current process.

While here, I also changed the error check for Linux
`rt_tgsigqueueinfo()` as it was not at all clear to me how we would ever
see `EPERM` from sending a signal to the current thread. Besides, it's
sensible to go to the `raise()` path as a last resort regardless of how
`rt_tgsigqueueinfo()` failed (e.g. `ENOSYS` on an old kernel).


  Commit: f6d9ec41d30b453c939bbaa1c73b876ce1389ee9
      https://github.com/llvm/llvm-project/commit/f6d9ec41d30b453c939bbaa1c73b876ce1389ee9
  Author: 陈子昂 <2802328816 at qq.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M clang/lib/Headers/riscv_packed_simd.h
    M clang/test/CodeGen/RISCV/rvp-intrinsics.c
    M cross-project-tests/intrinsic-header-tests/riscv_packed_simd.c

  Log Message:
  -----------
  [RISCV] Add packed narrowing convert intrinsics (#210389)

Add RISC-V P-extension packed narrowing convert header APIs for `pncvt`
and `pncvth`.

The new APIs lower through generic IR: RV32 uses truncate / logical
shift plus truncate forms, while RV64 uses existing packed unzip shuffle
forms. This reuses the existing backend lowering and TableGen aliases
rather than adding intrinsic-specific lowering.

Tests cover Clang IR generation and cross-project header assembly checks
for RV32/RV64 spec-listed mnemonics.


  Commit: be68a8829d6d6a2186f962b37d83984961cedeb1
      https://github.com/llvm/llvm-project/commit/be68a8829d6d6a2186f962b37d83984961cedeb1
  Author: Krzysztof Parzyszek <Krzysztof.Parzyszek at amd.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/Sequence.h

  Log Message:
  -----------
  [ADT] Fix non-assertion build after 36c812f771 (#210511)

E.g. https://lab.llvm.org/buildbot/#/builders/228/builds/5253


  Commit: 53096b7a2d268ab92617436915bc6f9f3cf8d82e
      https://github.com/llvm/llvm-project/commit/53096b7a2d268ab92617436915bc6f9f3cf8d82e
  Author: AntonyCJ30 <cj6186609 at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86ISelLowering.cpp
    M llvm/test/CodeGen/X86/apx/sub.ll

  Log Message:
  -----------
  [X86][APX] Optimize usub.sat(X,1) to cmp+adc with NDD (#208475)

When NDD is available, usub.sat(X, 1) is lowered from xor+sub+cmov (3
insns) to cmp+adc (2 insns).

All X86 tests pass.

Fixes #207888

Co-authored-by: AntonyCJ30 <cj6186609 at gmail@gmail.com>


  Commit: c739ce632b1489dcdbaad72df64a9cec9a8ed359
      https://github.com/llvm/llvm-project/commit/c739ce632b1489dcdbaad72df64a9cec9a8ed359
  Author: Taimuraz Kaitmazov <atassikay38 at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    A llvm/test/TableGen/subreg-index-overflow-allowed.td
    A llvm/test/TableGen/subreg-index-overflow.td
    M llvm/utils/TableGen/Common/CodeGenRegisters.cpp
    M llvm/utils/TableGen/Common/CodeGenRegisters.h

  Log Message:
  -----------
  [TableGen] Diagnose sub-register indices that overflow their register (#206346)


  Commit: 0b5073a3cd15b942860eeb2ce18a7958bbcf9169
      https://github.com/llvm/llvm-project/commit/0b5073a3cd15b942860eeb2ce18a7958bbcf9169
  Author: Jessica Clarke <jrtc27 at jrtc27.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M lld/ELF/InputSection.cpp
    M lld/ELF/Relocations.h

  Log Message:
  -----------
  [NFC][ELF] Remove unused R_RELAX_TLS_* RelExprs (#210517)

As of 46d29d43ba8e ("[ELF] Remove unused handleTlsRelocation (#184951)")
these are never generated.


  Commit: 2144ee4e19c4cf4501daed8d71aec68af1b9a8a6
      https://github.com/llvm/llvm-project/commit/2144ee4e19c4cf4501daed8d71aec68af1b9a8a6
  Author: Jessica Clarke <jrtc27 at jrtc27.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M lld/ELF/Relocations.h

  Log Message:
  -----------
  [NFC][ELF] Remove unused R_TLSDESC_CALL RelExpr (#210518)

As of 4ea72c1e8cbd ("[ELF] Add target-specific relocation scanning for
RISC-V (#181332)") this is never generated, and as of 46d29d43ba8e
("[ELF] Remove unused handleTlsRelocation (#184951)") this is not even
handled anywhere.


  Commit: f9b7acbe7d5b6dbd1769a8d8c9cfb6de23abe48c
      https://github.com/llvm/llvm-project/commit/f9b7acbe7d5b6dbd1769a8d8c9cfb6de23abe48c
  Author: Jessica Clarke <jrtc27 at jrtc27.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M lld/ELF/Relocations.h

  Log Message:
  -----------
  [NFC][ELF] Remove unused R_TLS*_HINT RelExprs (#210519)

As of 5e87f8147d68 ("[ELF] Add target-specific relocation scanning for
PPC32 (#181517)") these are never generated, and as of 46d29d43ba8e
("[ELF] Remove unused handleTlsRelocation (#184951)") these are not even
handled anywhere.


  Commit: acd3fcfdd6d065f914eadbe2036e703c056b4ccc
      https://github.com/llvm/llvm-project/commit/acd3fcfdd6d065f914eadbe2036e703c056b4ccc
  Author: Prabhu Rajasekaran <prabhukr at google.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M clang/lib/CodeGen/CodeGenModule.cpp
    M clang/lib/CodeGen/CodeGenModule.h
    M clang/test/CodeGen/call-graph-section-callback.cpp
    M clang/test/CodeGen/call-graph-section-internal.cpp
    M clang/test/CodeGen/call-graph-section-templates.cpp
    M clang/test/CodeGen/call-graph-section-virtual-methods.cpp
    M clang/test/CodeGen/call-graph-section.c
    M clang/test/CodeGen/call-graph-section.cpp
    M llvm/lib/CodeGen/AsmPrinter/AsmPrinter.cpp
    M llvm/lib/CodeGen/MachineFunction.cpp
    M llvm/lib/IR/Verifier.cpp
    M llvm/test/CodeGen/ARM/call-graph-section-addrtaken.ll
    M llvm/test/CodeGen/ARM/call-graph-section-assembly.ll
    M llvm/test/CodeGen/ARM/call-graph-section-tailcall.ll
    M llvm/test/CodeGen/ARM/call-graph-section.ll
    M llvm/test/CodeGen/X86/call-graph-section-addrtaken.ll
    M llvm/test/CodeGen/X86/call-graph-section-assembly.ll
    M llvm/test/CodeGen/X86/call-graph-section-tailcall.ll
    M llvm/test/CodeGen/X86/call-graph-section.ll
    M llvm/test/Verifier/callee-type-metadata.ll

  Log Message:
  -----------
  [clang] Emit call graph type metadata for internal linkage symbols (#210194)


  Commit: 4812a67a45710531f9ac3bf2a84a1e2b278971a4
      https://github.com/llvm/llvm-project/commit/4812a67a45710531f9ac3bf2a84a1e2b278971a4
  Author: Ayokunle Amodu <ayokunle321 at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-vi-f16.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn.hip

  Log Message:
  -----------
  [CIR][AMDGPU] Add support for AMDGCN frexp_mant builtins (#198121)

Adds codegen for the following AMDGCN frexp mantissa builtins:

- __builtin_amdgcn_frexp_mant (double)
- __builtin_amdgcn_frexp_mantf (float)
- __builtin_amdgcn_frexp_manth (half)

These are lowered to the corresponding `llvm.amdgcn.frexp.mant`
intrinsic.


  Commit: 6d70017b17f967756825107c91f24769046826b9
      https://github.com/llvm/llvm-project/commit/6d70017b17f967756825107c91f24769046826b9
  Author: Peter Collingbourne <peter at pcc.me.uk>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M .mailmap

  Log Message:
  -----------
  mailmap: Add entries for Peter Collingbourne. (#210526)

I am no longer at Google.


  Commit: d89537dd93f6fba07864e3583e11996c91a794b8
      https://github.com/llvm/llvm-project/commit/d89537dd93f6fba07864e3583e11996c91a794b8
  Author: Ilia Kuklin <ikuklin at accesssoftek.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Target/DirectX/DXContainerGlobals.cpp
    M llvm/lib/Target/DirectX/DXILWriter/DXILWriterPass.cpp

  Log Message:
  -----------
  [DirectX] Fix `--dx-embed-debug` flag dependency (#210513)

This patch moves the definition of `cl::opt<std::string> PdbDebugPath`
from `DXContainerGlobals.cpp` to `DXILWriter/DXILWriterPass.cpp`,
reversing the dependency.
Fixes the layering violation in #204166.


  Commit: 220e8277d3ad300c094447d214f0a5a122435196
      https://github.com/llvm/llvm-project/commit/220e8277d3ad300c094447d214f0a5a122435196
  Author: Alexis Engelke <engelke at in.tum.de>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/include/llvm/IR/PassManagerInternal.h
    M llvm/unittests/IR/PassManagerTest.cpp

  Log Message:
  -----------
  [IR][NFC] Avoid unneccessary move of analysis results (#210540)

While benchmarking CycleAnalysis, I noticed that each analysis result is
constructed on the stack first and then moved to its final place on the
heap. This is unnecessary -- directly construct the analysis result in
its final place. Consequently, analysis results can be immovable.


  Commit: bcb4e7d061ac22bce4ac65f5158a4746fb0edc0f
      https://github.com/llvm/llvm-project/commit/bcb4e7d061ac22bce4ac65f5158a4746fb0edc0f
  Author: Justin Lebar <justin.lebar at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/InstCombine/InstCombineSimplifyDemanded.cpp
    M llvm/test/Transforms/InstCombine/simplify-demanded-fpclass-fdiv.ll

  Log Message:
  -----------
  [InstCombine] Fix 0.0 / x -> 0 folds when the divisor may be zero (#202482)

SimplifyDemandedUseFPClass folded 0/x to a signed zero, guarded only on
the divisor being non-NaN. But when x==0, the result is is NaN, not 0!

Require the divisor to be never (logical) zero, unless a NaN result
isn't demanded.


  Commit: f5c4f390a04abf63f9f4c98980df67e22544ddb7
      https://github.com/llvm/llvm-project/commit/f5c4f390a04abf63f9f4c98980df67e22544ddb7
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyLateEHPrepare.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp

  Log Message:
  -----------
  [WebAssembly] Port WebAssemblyLateEHPreparePass

Standard NewPM pass porting.

Reviewers: aheejin, sbc100, dschuff

Pull Request: https://github.com/llvm/llvm-project/pull/209956


  Commit: 0e3d17a080646825df5cdff6997c633b6292b6ff
      https://github.com/llvm/llvm-project/commit/0e3d17a080646825df5cdff6997c633b6292b6ff
  Author: Aiden Grossman <aidengrossman at google.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblyReplacePhysRegs.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp

  Log Message:
  -----------
  [WebAssembly] Port WebAssemblyReplacePhysRegsPass

Standard NewPM pass porting.

Reviewers: dschuff, aheejin, sbc100

Pull Request: https://github.com/llvm/llvm-project/pull/209957


  Commit: 84b9da663e9c505304eac37621a56fd8e1ef7c12
      https://github.com/llvm/llvm-project/commit/84b9da663e9c505304eac37621a56fd8e1ef7c12
  Author: hulxv <hulxxv at gmail.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M .github/workflows/containers/libc/Dockerfile

  Log Message:
  -----------
  [Github] Install `llvm-tools` in libc container (#210414)

Currently, the libc container doesn't contain `llvm-tools`. we need to
use them in #200196 because we are not able to use `llvm-lit` without
building clang from source


  Commit: 14bf60dacab081559bedca01ab426f52793b38cb
      https://github.com/llvm/llvm-project/commit/14bf60dacab081559bedca01ab426f52793b38cb
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericCycleImpl.h

  Log Message:
  -----------
  [CycleInfo] Deduplicate getExitBlocks with a set. NFC (#210557)

Fix the O(exit_blocks^2) hazard.


  Commit: 617e4f54e503b54b08445a086d95a80aa72a58d0
      https://github.com/llvm/llvm-project/commit/617e4f54e503b54b08445a086d95a80aa72a58d0
  Author: aokblast <aokblast at FreeBSD.org>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M clang/lib/Interpreter/Interpreter.cpp

  Log Message:
  -----------
  [Clang][Interpreter] Don't pass -fPIC on MSVC (#210507)


  Commit: f05a649741f248e3809a6d0e7b5a8daf7bed74a8
      https://github.com/llvm/llvm-project/commit/f05a649741f248e3809a6d0e7b5a8daf7bed74a8
  Author: Anonmiraj <ezzibrahimx at gmail.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M libc/config/baremetal/aarch64/entrypoints.txt
    M libc/config/baremetal/arm/entrypoints.txt
    M libc/config/baremetal/riscv/entrypoints.txt
    M libc/config/darwin/aarch64/entrypoints.txt
    M libc/config/gpu/amdgpu/entrypoints.txt
    M libc/config/gpu/nvptx/entrypoints.txt
    M libc/config/linux/aarch64/entrypoints.txt
    M libc/config/linux/riscv/entrypoints.txt
    M libc/config/linux/x86_64/entrypoints.txt
    M libc/docs/headers/math/index.rst
    M libc/include/math.yaml
    M libc/shared/math.h
    A libc/shared/math/lgammaf16.h
    M libc/src/__support/math/CMakeLists.txt
    A libc/src/__support/math/lgammaf16.h
    M libc/src/math/CMakeLists.txt
    M libc/src/math/generic/CMakeLists.txt
    A libc/src/math/generic/lgammaf16.cpp
    A libc/src/math/lgammaf16.h
    M libc/test/shared/CMakeLists.txt
    M libc/test/shared/shared_math_test.cpp
    M libc/test/src/math/CMakeLists.txt
    A libc/test/src/math/lgammaf16_test.cpp
    M libc/test/src/math/smoke/CMakeLists.txt
    A libc/test/src/math/smoke/lgammaf16_test.cpp
    M libc/utils/MPFRWrapper/MPCommon.cpp
    M libc/utils/MPFRWrapper/MPCommon.h
    M libc/utils/MPFRWrapper/MPFRUtils.cpp
    M libc/utils/MPFRWrapper/MPFRUtils.h
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel

  Log Message:
  -----------
  [libc][math] Implement half precision lgamma function (#192834)

The implementation uses three distinct paths based on $|x|$:

- Small ($|x| < 0.66$): Fits a degree-12 Chebyshev for $h(t) =
\frac{\text{lgamma}(t) + \log(t)}{t}$, recovering $\text{lgamma}(t) = t
\cdot h - \log(t)$.

- Medium ($|x| \in [0.66, 3.37]$): Fits a degree-20 Chebyshev for $g(t)
= \frac{\text{lgamma}(t)}{(t-1)(t-2)}$
- Stirling ($|x| > 3.37$): Uses $(x-0.5) \cdot \log(x) - x +
\frac{\log(2\pi)}{2}$ plus 1/2/4/8-term Bernoulli corrections by
sub-range.


Special cases: NaN, +/-Inf -> +Inf, +/-0 pole, negative integer pole,
lgamma(1) = lgamma(2) = 0 exactly, overflow for large positive x.

Exhaustive tests pass in all 4 rounding modes.

-- CORE-MATH reciprocal throughput --
Ntrial = 20 ; Min = 391.348 + 77.447 clc/call; Median-Min = 68.093
clc/call; Max = 540.055 clc/call;
-- System LIBC reciprocal throughput --
Ntrial = 20 ; Min = 377.829 + 81.686 clc/call; Median-Min = 64.851
clc/call; Max = 532.888 clc/call;


  Commit: 81ed4d01aa5858ab3f3ffe4e5cc4f9111a8afc46
      https://github.com/llvm/llvm-project/commit/81ed4d01aa5858ab3f3ffe4e5cc4f9111a8afc46
  Author: Fangrui Song <i at maskray.me>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/GenericUniformityImpl.h

  Log Message:
  -----------
  [UniformityAnalysis] Replace DenseMap with SmallVector indexed by block number. NFC (#210564)


  Commit: 8043ceb7591cc1e55e699cbf8f23fffe1e90381f
      https://github.com/llvm/llvm-project/commit/8043ceb7591cc1e55e699cbf8f23fffe1e90381f
  Author: Petr Hosek <phosek at google.com>
  Date:   2026-07-18 (Sat, 18 Jul 2026)

  Changed paths:
    M libc/cmake/modules/LLVMLibCCompileOptionRules.cmake

  Log Message:
  -----------
  [libc] Omit -fpie from the full build (#208343)

We shouldn't unconditionally set -fpie, users should be able to control
this with CMAKE_POSITION_INDEPENDENT_CODE.


  Commit: 446a84a7c66eda9b945a000ccab04948f240eaaa
      https://github.com/llvm/llvm-project/commit/446a84a7c66eda9b945a000ccab04948f240eaaa
  Author: Brad Smith <brad at comstyle.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M openmp/runtime/src/kmp_i18n.cpp

  Log Message:
  -----------
  [OpenMP] Simplify GNU strerror_r check for Android (#148990)

Android 6 is the baseline so simplify the Android check.


  Commit: 790882669323c7255cb761755bb2d37d3b344452
      https://github.com/llvm/llvm-project/commit/790882669323c7255cb761755bb2d37d3b344452
  Author: Shikhar Jain <shikharj at qti.qualcomm.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M polly/include/polly/DependenceInfo.h
    M polly/lib/Analysis/DependenceInfo.cpp
    M polly/lib/CodeGen/IslAst.cpp
    A polly/test/IstAstInfo/AstGenComputeOut.ll

  Log Message:
  -----------
  [Polly] Guard ISL ast gen compute out (#201859)

Bounds the maximum ISL operations allowed for ISL AST Generation.

Fixes: https://github.com/llvm/llvm-project/issues/201801


  Commit: f988efbef5854243f9f518e9334dfee08ff2e1de
      https://github.com/llvm/llvm-project/commit/f988efbef5854243f9f518e9334dfee08ff2e1de
  Author: michaelselehov <michael.selehov at amd.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.cpp
    M llvm/test/CodeGen/AMDGPU/print-pipeline-passes.ll
    M llvm/test/Transforms/PhaseOrdering/AMDGPU/infer-address-space.ll

  Log Message:
  -----------
  [AMDGPU] Run early-cse<memssa> at the end of the full-LTO pipeline (#208461)

The regular (non-LTO) and ThinLTO function simplification pipelines run
an
EarlyCSE-with-MemorySSA pass near the start of the function pass
sequence, but
the full-LTO postlink pipeline does not. Without it, a redundant
load/store
round-trip can survive all the way to codegen; the later GVN/DSE in the
LTO
pipeline do not catch this particular pattern. 
    
Rather than touch the target-independent LTO pipeline, register
early-cse<memssa> through the AMDGPU FullLinkTimeOptimizationLast
extension
point, so it runs at the end of the full-LTO middle-end (before codegen)
only
for AMDGPU.
    
    Assisted-by: Claude Opus


  Commit: 4a1c00420f7e1660d509ac32ca3d02a4aef20ab2
      https://github.com/llvm/llvm-project/commit/4a1c00420f7e1660d509ac32ca3d02a4aef20ab2
  Author: David Zbarsky <dzbarsky at gmail.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/include/llvm/MC/MCSchedule.h
    M llvm/test/TableGen/CompressWriteLatencyEntry.td
    M llvm/utils/TableGen/SubtargetEmitter.cpp

  Log Message:
  -----------
  [MC] Pack scheduling class entry counts (#202649)

Generated scheduling classes currently use at most 20 write-resource
entries and 35 write-latency entries, while read-advance counts reach
504. Narrow the two write counts to `uint8_t`, order the three table
indices before the three counts, and emit target-specific compile-time
bounds assertions in generated subtarget source.

This reduces `sizeof(MCSchedClassDesc)` from 14 to 12 bytes in release
builds and from 20 to 16 bytes with debug fields. Fully stripped arm64
`llvm-mca` decreases by 544,896 bytes (1.49%), and the stripped
all-tools multicall binary decreases by 528,376 bytes (0.368%).

Work towards #202616

AI tool disclosure: Co-authored with OpenAI Codex.


  Commit: ee62806354aabac85ef8c6605bdc7829d997682a
      https://github.com/llvm/llvm-project/commit/ee62806354aabac85ef8c6605bdc7829d997682a
  Author: Kevin Sala Penades <salapenades1 at llnl.gov>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M clang/docs/OpenMPSupport.md
    M clang/docs/ReleaseNotes.md
    M clang/include/clang/AST/OpenMPClause.h
    M clang/include/clang/AST/RecursiveASTVisitor.h
    M clang/include/clang/Basic/DiagnosticSemaKinds.td
    M clang/include/clang/Basic/OpenMPKinds.def
    M clang/include/clang/Basic/OpenMPKinds.h
    M clang/include/clang/Sema/SemaOpenMP.h
    M clang/lib/AST/OpenMPClause.cpp
    M clang/lib/AST/StmtProfile.cpp
    M clang/lib/Basic/OpenMPKinds.cpp
    M clang/lib/Parse/ParseOpenMP.cpp
    M clang/lib/Sema/SemaOpenMP.cpp
    M clang/lib/Sema/TreeTransform.h
    M clang/lib/Serialization/ASTReader.cpp
    M clang/lib/Serialization/ASTWriter.cpp
    A clang/test/OpenMP/dims_modifier_ast_print.cpp
    A clang/test/OpenMP/dims_modifier_messages.cpp
    M clang/test/OpenMP/ompx_bare_messages.c
    M clang/test/OpenMP/target_teams_distribute_num_teams_messages.cpp
    M clang/test/OpenMP/target_teams_distribute_parallel_for_num_teams_messages.cpp
    M clang/test/OpenMP/teams_num_teams_messages.cpp
    M clang/tools/libclang/CIndex.cpp

  Log Message:
  -----------
  [Clang][OpenMP] Add parsing/sema for dims modifier in num_teams and thread_limit (#206412)

Add parsing and sema support for `dims` modifier (OpenMP 6.1) in `num_teams` and
`thread_limit` clauses. Example:

```cpp
constexpr int N = 2;
#pragma omp teams num_teams(dims(3): x, y, z) thread_limit(dims(N): a, b)
{ ... }
```


  Commit: 8042e61d6ae99347e8cab040b324b33cabfb1d4a
      https://github.com/llvm/llvm-project/commit/8042e61d6ae99347e8cab040b324b33cabfb1d4a
  Author: Andreas Jonson <andjo403 at hotmail.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/InstCombine/InstCombineCasts.cpp
    M llvm/test/Transforms/InstCombine/trunc.ll

  Log Message:
  -----------
  [InstCombine] Fold trunc nuw/nsw (shr exact %x, %y) to i1 -> icmp ne %x, 0 (#210499)

Proof: https://alive2.llvm.org/ce/z/de6gru


  Commit: 5cae63bd0d31118a15481fc7e5b063a73492d77d
      https://github.com/llvm/llvm-project/commit/5cae63bd0d31118a15481fc7e5b063a73492d77d
  Author: Michael Kruse <llvm-project at meinersbur.de>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M polly/test/IstAstInfo/AstGenComputeOut.ll

  Log Message:
  -----------
  [Polly][test] Add missing REQUIRES line (#210578)

The test was added by #201859. It's test uses --debug-only which
requires an LLVM_ENABLE_ASSERTIONS-build


  Commit: 1d55a816c6dddfaacfd39f3235519a2389b56423
      https://github.com/llvm/llvm-project/commit/1d55a816c6dddfaacfd39f3235519a2389b56423
  Author: Mikołaj Piróg <mikolaj.maciej.pirog at intel.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M clang/lib/Basic/Targets/X86.cpp
    M clang/test/CodeGen/attr-target-mv.c
    M clang/test/CodeGen/attr-target-x86.c
    M clang/test/Sema/attr-target-mv.c
    M clang/test/Sema/attr-target.c
    M llvm/include/llvm/TargetParser/X86TargetParser.def

  Log Message:
  -----------
  [X86] Support apxf in attribute target (#184078)

As in title. This adds support for using apxf in attribute target.
Individual features are not supported for FMV but are supported for
enabling a feature for the function

Patch done with usage of Claude Code.


  Commit: 5e1873abad44f622c7a18304b1552c233d47bd16
      https://github.com/llvm/llvm-project/commit/5e1873abad44f622c7a18304b1552c233d47bd16
  Author: Krzysztof Parzyszek <Krzysztof.Parzyszek at amd.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M flang/lib/Parser/openmp-parsers.cpp
    M llvm/include/llvm/Frontend/OpenMP/OMP.h
    M llvm/lib/Frontend/OpenMP/OMP.cpp
    M llvm/unittests/Frontend/OpenMPDirectiveNameParserTest.cpp

  Log Message:
  -----------
  [OpenMP] Add constexpr enum ranges for all clauses and all directives (#210406)

<sub>Stack created with <a
href="https://github.com/github/gh-stack">GitHub Stacks CLI</a> • <a
href="https://gh.io/stacks-feedback">Give Feedback 💬</a></sub>


  Commit: f25b3f62cee27d11d1491bdb10dfa955213b2064
      https://github.com/llvm/llvm-project/commit/f25b3f62cee27d11d1491bdb10dfa955213b2064
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    A llvm/test/Analysis/LoopAccessAnalysis/non-affine-monotonic-bounds.ll
    A llvm/test/Transforms/LoopVectorize/AArch64/non-affine-monotonic-bounds.ll
    A llvm/test/Transforms/LoopVectorize/non-affine-monotonic-bounds.ll

  Log Message:
  -----------
  [LAA,LV] Add tests for non-affine monotonic pointer bounds (NFC). (#210544)

Add test cases with non-affine monotonic pointer bounds, like for
example when using std::bitset.

Initial sets of tests for
https://github.com/llvm/llvm-project/issues/207882.


  Commit: cd99637821097c239b665793243d8e6a332fc719
      https://github.com/llvm/llvm-project/commit/cd99637821097c239b665793243d8e6a332fc719
  Author: Vito Secona <77039267+secona at users.noreply.github.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M mlir/lib/Dialect/Bufferization/Transforms/BufferDeallocationSimplification.cpp
    M mlir/test/Dialect/Bufferization/Transforms/buffer-deallocation-simplification.mlir

  Log Message:
  -----------
  [mlir][bufferization] Fix stale BufferOriginAnalysis in BufferDeallocationSimplification (#210105)

Fixes #205228

This change fixes a use-after-free bug in the
BufferDeallocationSimplification pipeline caused by the greedy pattern
rewriter deleting operation tracked by the BufferOriginAnalysis.
BufferViewFlowAnalysis (internally used by BufferOriginAnalysis) creates
the dependencies map once during initialization. In this specific case,
the folder removed the `memref.cast` ops making later uses a
use-after-free bug.

Below is the snippet of running the pass using
`-debug-only=greedy-rewriter`. It erases a `memref.cast` and crashes in
RemoveDeallocMemrefsContainedInRetained.

```
...
[greedy-rewriter:1] //===-------------------------------------------===//
[greedy-rewriter:1] Processing operation : 'memref.cast'(0x654d43d18670) {
[greedy-rewriter:1]   %4 = "memref.cast"(%3) : (memref<?x?xf32, 1>) -> memref<4x4xf32, 1>
[greedy-rewriter:1] 
[greedy-rewriter:1] } -> success : operation was folded
[greedy-rewriter:1] //===-------------------------------------------===//
[greedy-rewriter:1] ** Replace : 'memref.cast'(0x654d43d18670)
[greedy-rewriter:1] ** Modified: 'scf.yield'(0x654d43c97bb0)
[greedy-rewriter:1] ** Erase   : 'memref.cast'(0x654d43d18670)
...
[greedy-rewriter:1] Processing operation : 'bufferization.dealloc'(0x654d43cbd7d0) {
[greedy-rewriter:1]   %5 = "bufferization.dealloc"(%4#0, %1, %3) <{operandSegmentSizes = array<i32: 1, 1, 1>}> : (memref<f32, 1>, i1, memref<4x4xf32, 1>) -> i1
[greedy-rewriter:1] 
[greedy-rewriter:1] 
[greedy-rewriter:1]   * Pattern (anonymous namespace)::RemoveDeallocMemrefsContainedInRetained : 'bufferization.dealloc -> ()' {
```

The fix is to disable folding and split the canonicalization patterns to
run separately. This way, the patterns that rely on BufferOriginAnalysis
still work because folding was disabled and BufferOriginAnalysis never
invalidated. Then, the canonicalization patterns still benefit from
folding.


  Commit: 4b4d4a61202bd960a7a72730d596e5ebe6ab71b1
      https://github.com/llvm/llvm-project/commit/4b4d4a61202bd960a7a72730d596e5ebe6ab71b1
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/AArch64/masked-div-rem-non-pow2.ll

  Log Message:
  -----------
  [SLP][NFC]Add a test for potential masked div/rem ops, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210593


  Commit: 5c7dc8e7d72e8f833e5fa4d4790e93ff76b51304
      https://github.com/llvm/llvm-project/commit/5c7dc8e7d72e8f833e5fa4d4790e93ff76b51304
  Author: Lucas Mellone <github.snugness349 at passinbox.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M libcxx/test/libcxx/ranges/range.adaptors/range.enumerate/nodiscard.verify.cpp

  Log Message:
  -----------
  [libc++][ranges] Add missing test cases for `[[nodiscard]]` tests in `enumerate_view` (#209289)

Addresses missing `[[nodiscard]]` test cases for
`std::views::enumerate`.

---------

Co-authored-by: Hristo Hristov <zingam at outlook.com>


  Commit: ab39c491430e1f327849708ababffa3458b8ff6f
      https://github.com/llvm/llvm-project/commit/ab39c491430e1f327849708ababffa3458b8ff6f
  Author: Feng Zou <feng.zou at intel.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Target/X86/X86FlagsCopyLowering.cpp
    M llvm/lib/Target/X86/X86InstrInfo.cpp
    M llvm/lib/Target/X86/X86InstrInfo.h
    M llvm/test/CodeGen/X86/apx/add.ll
    M llvm/test/CodeGen/X86/apx/flags-copy-lowering.ll
    A llvm/test/CodeGen/X86/apx/optimize-compare-multipred.ll
    A llvm/test/CodeGen/X86/apx/optimize-compare-multipred.mir

  Log Message:
  -----------
  [X86][APX] Reuse EFLAGS across multi-predecessor blocks via NF in optimizeCompareInstr (#208184)

Extend optimizeCompareInstr to reuse EFLAGS produced in predecessor
blocks (including via NF variants) when a compare is redundant, covering
multi-predecessor, dominating, and cyclic CFGs. Share the NF-clobber
removal helper with FlagsCopyLowering, correctly handle swapped and
immediate-adjusted flag reuse, and simplify EFLAGS live-in marking.

Adds MIR tests exercising multi-predecessor reuse over cyclic and
dominating CFGs, including a multi-level idom walk.

Assisted-By: Claude Opus 4.8


  Commit: 637506427c2062fdbbd52fe1ef6c701f799a4228
      https://github.com/llvm/llvm-project/commit/637506427c2062fdbbd52fe1ef6c701f799a4228
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    A llvm/test/Transforms/SLPVectorizer/AArch64/masked-div-rem-non-pow2-revec.ll

  Log Message:
  -----------
  [SLP][NFC]Add a test with potential masked revec udiv, NFC



Reviewers: 

Pull Request: https://github.com/llvm/llvm-project/pull/210596


  Commit: 9f6c84b8361133ecea5a43e34ab020384085a931
      https://github.com/llvm/llvm-project/commit/9f6c84b8361133ecea5a43e34ab020384085a931
  Author: hulxv <hulxxv at gmail.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M .github/workflows/containers/libc/Dockerfile

  Log Message:
  -----------
  [Github] symlink `llvm-tools` in libc container (#210561)

Missed thing in #210414. We need to symlink the LLVM tools that are
under `/usr/lib/llvm-23/bin/` to avoid errors like this because the LLVM
tools have a `-23` suffix when they're installed inside the container

```
# RUN: at line 2
/usr/bin/clang-23   -gline-tables-only   -Wthread-safety -Wthread-safety-reference -Wthread-safety-beta  -DCOMPILER_RT_HAS_FLOAT16 -nobuiltininc -I/__w/llvm-project/llvm-project/compiler-rt/include -idirafter /usr/lib/llvm-23/lib/clang/23/include -resource-dir=/__w/llvm-project/llvm-project/build/compiler-rt -Wl,-rpath,/__w/llvm-project/llvm-project/build/compiler-rt/lib/linux  -fno-builtin -I /__w/llvm-project/llvm-project/compiler-rt/lib/builtins -nodefaultlibs /__w/llvm-project/llvm-project/compiler-rt/test/builtins/Unit/aarch64/emupac.c -lm -Wl,--start-group /__w/llvm-project/llvm-project/build/compiler-rt/lib/linux/libclang_rt.builtins-aarch64.a -lc -Wl,--end-group -o /__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp
# executed command: /usr/bin/clang-23 -gline-tables-only -Wthread-safety -Wthread-safety-reference -Wthread-safety-beta -DCOMPILER_RT_HAS_FLOAT16 -nobuiltininc -I/__w/llvm-project/llvm-project/compiler-rt/include -idirafter /usr/lib/llvm-23/lib/clang/23/include -resource-dir=/__w/llvm-project/llvm-project/build/compiler-rt -Wl,-rpath,/__w/llvm-project/llvm-project/build/compiler-rt/lib/linux -fno-builtin -I /__w/llvm-project/llvm-project/compiler-rt/lib/builtins -nodefaultlibs /__w/llvm-project/llvm-project/compiler-rt/test/builtins/Unit/aarch64/emupac.c -lm -Wl,--start-group /__w/llvm-project/llvm-project/build/compiler-rt/lib/linux/libclang_rt.builtins-aarch64.a -lc -Wl,--end-group -o /__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp
# RUN: at line 3
/__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp 1
# executed command: /__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp 1
# RUN: at line 4
/__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp 2
# executed command: /__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp 2
# RUN: at line 5
not --crash  /__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp 3
# executed command: not --crash /__w/llvm-project/llvm-project/build/compiler-rt/test/builtins/Unit/AARCH64LinuxConfig/aarch64/Output/emupac.c.tmp 3
# .---command stderr------------
# | 'not': command not found
# `-----------------------------
```


  Commit: dcf03fefd46ea1426475c948925c9501af2f5495
      https://github.com/llvm/llvm-project/commit/dcf03fefd46ea1426475c948925c9501af2f5495
  Author: Kazu Hirata <kazu at google.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/include/llvm/ADT/Eytzinger.h
    M llvm/unittests/ADT/EytzingerTest.cpp

  Log Message:
  -----------
  [ADT] Add begin and end to EytzingerTableSpan and EytzingerTable (NFC) (#210478)

This patch adds iterator and const_iterator type aliases as well as
begin() and end() methods to EytzingerTableSpan and EytzingerTable.

I'm going to be using these as part of the SecNameTable in the
Eytzinger layout.

RFC:
https://discourse.llvm.org/t/rfc-faster-sample-profile-loading/90957/8

Assisted-by: Antigravity


  Commit: 24942433bc8a71b8aa459f802a0962089bb4dd22
      https://github.com/llvm/llvm-project/commit/24942433bc8a71b8aa459f802a0962089bb4dd22
  Author: Mend Renovate <bot at renovateapp.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M .github/workflows/bazel-checks.yml
    M .github/workflows/build-ci-container-tooling.yml
    M .github/workflows/build-ci-container-windows.yml
    M .github/workflows/build-ci-container.yml
    M .github/workflows/build-libc-container.yml
    M .github/workflows/build-metrics-container.yml
    M .github/workflows/check-ci.yml
    M .github/workflows/ci-post-commit-analyzer.yml
    M .github/workflows/commit-access-greeter.yml
    M .github/workflows/commit-access-review.yml
    M .github/workflows/docs.yml
    M .github/workflows/email-check.yaml
    M .github/workflows/gha-codeql.yml
    M .github/workflows/hlsl-test-all.yaml
    M .github/workflows/ids-check.yml
    M .github/workflows/issue-release-workflow.yml
    M .github/workflows/issue-write.yml
    M .github/workflows/libc-freebsd-vm-tests.yml
    M .github/workflows/libc-fullbuild-tests.yml
    M .github/workflows/libc-overlay-tests.yml
    M .github/workflows/libc-shared-tests.yml
    M .github/workflows/libclang-abi-tests.yml
    M .github/workflows/libcxx-benchmark-commit.yml
    M .github/workflows/libcxx-build-and-test.yaml
    M .github/workflows/libcxx-build-containers.yml
    M .github/workflows/libcxx-check-generated-files.yml
    M .github/workflows/libcxx-pr-benchmark.yml
    M .github/workflows/lldb-pylint-action.yml
    M .github/workflows/llvm-abi-tests.yml
    M .github/workflows/llvm-bugs.yml
    M .github/workflows/merged-prs.yml
    M .github/workflows/mlir-spirv-tests.yml
    M .github/workflows/new-issues.yml
    M .github/workflows/new-prs.yml
    M .github/workflows/pr-code-format.yml
    M .github/workflows/pr-code-lint.yml
    M .github/workflows/premerge.yaml
    M .github/workflows/prune-branches.yml
    M .github/workflows/release-asset-audit.yml
    M .github/workflows/release-binaries.yml
    M .github/workflows/release-documentation.yml
    M .github/workflows/release-doxygen.yml
    M .github/workflows/release-llvm-testing-tools.yml
    M .github/workflows/release-sources.yml
    M .github/workflows/release-tasks.yml
    M .github/workflows/require-team-membership/action.yml
    M .github/workflows/scorecard.yml
    M .github/workflows/spirv-tests.yml
    M .github/workflows/subscriber.yml
    M .github/workflows/sycl-tests.yml
    M .github/workflows/test-suite.yml
    M .github/workflows/test-unprivileged-download-artifact.yml
    M .github/workflows/upload-release-artifact/action.yml
    M .github/workflows/version-check.yml
    M .github/workflows/zizmor.yml

  Log Message:
  -----------
  Update [Github] Update GHA Dependencies (#194274)

This PR contains the following updates:

| Package | Type | Update | Change | Pending |
|---|---|---|---|---|
|
[EnricoMi/publish-unit-test-result-action](https://redirect.github.com/EnricoMi/publish-unit-test-result-action)
| action | minor | `v2.23.0` → `v2.24.0` | |
|
[actions/attest-build-provenance](https://redirect.github.com/actions/attest-build-provenance)
| action | patch | `v4.1.0` → `v4.1.1` | |
| [actions/checkout](https://redirect.github.com/actions/checkout) |
action | patch | `v6.0.2` → `v6.0.3` | |
| [actions/checkout](https://redirect.github.com/actions/checkout) |
action | patch | `v6.0.1` → `v6.0.3` | |
|
[actions/create-github-app-token](https://redirect.github.com/actions/create-github-app-token)
| action | minor | `v3.1.1` → `v3.2.0` | |
| [actions/labeler](https://redirect.github.com/actions/labeler) |
action | minor | `v6.0.1` → `v6.2.0` | |
| [actions/setup-node](https://redirect.github.com/actions/setup-node) |
action | minor | `v6.3.0` → `v6.5.0` | |
|
[actions/setup-python](https://redirect.github.com/actions/setup-python)
| action | minor | `v6.2.0` → `v6.3.0` | |
|
[actions/upload-artifact](https://redirect.github.com/actions/upload-artifact)
| action | patch | `v7.0.0` → `v7.0.1` | |
| [aminya/setup-cpp](https://redirect.github.com/aminya/setup-cpp) |
action | patch | `v1.8.0` → `v1.8.1` | |
| [docker/login-action](https://redirect.github.com/docker/login-action)
| action | minor | `v4.1.0` → `v4.4.0` | |
| ghcr.io/llvm/amd64/ci-ubuntu-24.04-github-automation | container |
digest | `82b5304` → `f419363` | |
| ghcr.io/llvm/ci-ubuntu-24.04 | container | digest | `cc4fd65` →
`26c16c2` | |
| ghcr.io/llvm/ci-ubuntu-24.04-abi-tests | container | digest |
`cb3aea3` → `a948062` | |
| ghcr.io/llvm/ci-ubuntu-24.04-lint | container | digest | `91665a4` →
`416874e` | |
| ghcr.io/llvm/libc-ubuntu-24.04 | container | digest | `a902fb5` →
`b9c8ea7` | |
|
[github/codeql-action](https://redirect.github.com/github/codeql-action)
| action | minor | `v4.35.2` → `v4.37.0` | `v4.37.1` |
|
[hendrikmuhs/ccache-action](https://redirect.github.com/hendrikmuhs/ccache-action)
| action | patch | `v1.2.22` → `v1.2.23` | |
|
[zizmorcore/zizmor-action](https://redirect.github.com/zizmorcore/zizmor-action)
| action | minor | `v0.5.3` → `v0.6.0` | |


  Commit: c45b4e4d00bed488d6ece5608560561732ae5b9e
      https://github.com/llvm/llvm-project/commit/c45b4e4d00bed488d6ece5608560561732ae5b9e
  Author: Brian Cain <brian.cain at oss.qualcomm.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M clang/lib/Driver/ToolChains/Hexagon.cpp
    M clang/test/Driver/hexagon-toolchain-linux.c

  Log Message:
  -----------
  [Hexagon] Link static PIE executables against rcrt1.o (#210125)

We always selected crt1.o as the CRT start file, regardless of link
mode.

Select rcrt1.o - the self-relocating static-PIE start file when -static
and PIE are active


  Commit: 32819927e0c02662a5c8aae252997748cdc94962
      https://github.com/llvm/llvm-project/commit/32819927e0c02662a5c8aae252997748cdc94962
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/LoopVectorizationPlanner.h
    M llvm/lib/Transforms/Vectorize/LoopVectorize.cpp

  Log Message:
  -----------
  [VPlan] Retire LVP::hasTailFolded (NFC). (#210598)

LVP::hasTailFolded incldued an assert that hasTailFOlded matches the
VPlan version. No divergences surfaced, so remove the assert as planned.


  Commit: dae991a55eacb4f3c3382f3cba2897ceb43e1725
      https://github.com/llvm/llvm-project/commit/dae991a55eacb4f3c3382f3cba2897ceb43e1725
  Author: Justin Lebar <justin.lebar at gmail.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Analysis/AliasAnalysis.cpp
    M llvm/test/Analysis/BasicAA/atomics.ll

  Log Message:
  -----------
  [AA] Use the cmpxchg merged ordering in getModRefInfo (#210545)

When a cmpxchg's address is NoAlias with the queried location,
getModRefInfo still reports sync effects if the cmpxchg is stronger than
monotonic, since an ordered operation constrains code motion around
locations it never accesses.

But a cmpxchg op has two atomic orderings, and getModRefInfo looked
only at one of them.

Change it so we check the merged ordering, i.e. the stronger of the two.


  Commit: ae023494fba615bb1c75292f93e4521cfe7068b5
      https://github.com/llvm/llvm-project/commit/ae023494fba615bb1c75292f93e4521cfe7068b5
  Author: Alexey Bataev <a.bataev at outlook.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/test/Transforms/SLPVectorizer/X86/debug-info-salvage.ll
    M llvm/test/Transforms/SLPVectorizer/X86/minmax-main-opcode-copyables-cost.ll
    M llvm/test/Transforms/SLPVectorizer/X86/minmax-main-opcode-copyables.ll
    M llvm/test/Transforms/SLPVectorizer/X86/split-node-num-operands.ll
    M llvm/test/Transforms/SLPVectorizer/splat-buildvector.ll

  Log Message:
  -----------
  [SLP]Add umax/umin/smax/smin as main opcodes for copyables

Added umax/umin/smax/smin intrinsics in for copyables support.

Reviewers: hiraditya, bababuck, RKSimon

Pull Request: https://github.com/llvm/llvm-project/pull/209326


  Commit: 6bcdcb39c57ea926d3082ec3ecae74bf59b4658e
      https://github.com/llvm/llvm-project/commit/6bcdcb39c57ea926d3082ec3ecae74bf59b4658e
  Author: Jonas Devlieghere <jonas at devlieghere.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/DWARFLinker/Parallel/SyntheticTypeNameBuilder.cpp

  Log Message:
  -----------
  [DWARFLinker] Make synthetic type names deterministic under threading (#209553)


  Commit: 598f15297528855682dcf381575a9c14a7faabc3
      https://github.com/llvm/llvm-project/commit/598f15297528855682dcf381575a9c14a7faabc3
  Author: Florian Hahn <flo at fhahn.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/test/Transforms/ConstraintElimination/constraint-overflow.ll

  Log Message:
  -----------
  [ConstraintElim] Fix integer overflow when negating constraint (#210627)

Negating a coefficient (e.g. INT64_MIN) can overflow; skip adding the
inverted constraint if it wraps.

Fixes an UBSan failure for the added test.


  Commit: 01683dbe7e2071e8cc3aa2874e623259079aa1ae
      https://github.com/llvm/llvm-project/commit/01683dbe7e2071e8cc3aa2874e623259079aa1ae
  Author: Lang Hames <lhames at gmail.com>
  Date:   2026-07-20 (Mon, 20 Jul 2026)

  Changed paths:
    M orc-rt/include/orc-rt/QueueingRunner.h
    M orc-rt/include/orc-rt/Session.h
    M orc-rt/lib/executor/Session.cpp
    M orc-rt/test/unit/CommonTestUtils.h
    M orc-rt/test/unit/InProcessControllerAccessTest.cpp
    M orc-rt/test/unit/QueueingRunnerTest.cpp

  Log Message:
  -----------
  [orc-rt] Replace RunWrapperCall with generalized Dispatch (#210591)

RunWrapperCall dispatched wrapper-function calls, but the Session also
needs to dispatch continuations for results returned by the controller.
Replace it with a generalized Dispatch mechanism (DispatchFn) that is
handed an opaque Task for each unit of work, covering both.

QueueingRunner is correspondingly simplified: it no longer knows
anything about wrapper functions and just enqueues the Task it is given.
Tests and the noDispatch helper are updated to the new interface.


  Commit: 16ffd27e3737c01cbabad6eed77b919dc977ad6c
      https://github.com/llvm/llvm-project/commit/16ffd27e3737c01cbabad6eed77b919dc977ad6c
  Author: Petr Hosek <phosek at google.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M libcxx/src/support/runtime/exception_pointer_msvc.ipp

  Log Message:
  -----------
  [libcxx][NFC] Address -Wmicrosoft-cast in MSVC's exception_ptr (#210570)

This was introduced as part of #94977. Rather than suppressing the
warning with `#pragma clang diagnostic ignored`, we use
`reinterpret_cast` to avoid the implicit conversion.


  Commit: c6672a6fdf1469d818d0ac8aaa2c31a0f18e729a
      https://github.com/llvm/llvm-project/commit/c6672a6fdf1469d818d0ac8aaa2c31a0f18e729a
  Author: Benji Smith <6193112+Benjins at users.noreply.github.com>
  Date:   2026-07-19 (Sun, 19 Jul 2026)

  Changed paths:
    M llvm/lib/Transforms/InstCombine/InstCombineCalls.cpp
    M llvm/test/Transforms/InstCombine/fsh.ll

  Log Message:
  -----------
  [InstCombine] Fix invalid fshl -> lshr fold when shift is vector with constant zero lane (#210606)

For vectors, this is not valid if a subset of the lanes are constant
zero. Doing this fold introduces poison in those lanes. A similar fix
was done for fshr in 46957a138dea339799059ea5bf032e40042ff185 however
the same issue seems to apply to fshl

Fixes https://github.com/llvm/llvm-project/issues/210605


  Commit: 126d90ac9593362d30b8722f6b374be7e4fcb366
      https://github.com/llvm/llvm-project/commit/126d90ac9593362d30b8722f6b374be7e4fcb366
  Author: Tony Varghese <tonypalampalliyil at gmail.com>
  Date:   2026-07-20 (Mon, 20 Jul 2026)

  Changed paths:
    M .ci/compute_projects.py
    M .ci/compute_projects_test.py
    M .github/workflows/bazel-checks.yml
    M .github/workflows/build-ci-container-tooling.yml
    M .github/workflows/build-ci-container-windows.yml
    M .github/workflows/build-ci-container.yml
    M .github/workflows/build-libc-container.yml
    M .github/workflows/build-metrics-container.yml
    M .github/workflows/check-ci.yml
    M .github/workflows/ci-post-commit-analyzer.yml
    M .github/workflows/commit-access-greeter.yml
    M .github/workflows/commit-access-review.yml
    M .github/workflows/containers/libc/Dockerfile
    M .github/workflows/docs.yml
    M .github/workflows/email-check.yaml
    M .github/workflows/gha-codeql.yml
    M .github/workflows/hlsl-test-all.yaml
    M .github/workflows/ids-check.yml
    M .github/workflows/issue-release-workflow.yml
    M .github/workflows/issue-write.yml
    M .github/workflows/libc-freebsd-vm-tests.yml
    M .github/workflows/libc-fullbuild-tests.yml
    M .github/workflows/libc-overlay-tests.yml
    M .github/workflows/libc-shared-tests.yml
    M .github/workflows/libclang-abi-tests.yml
    M .github/workflows/libcxx-benchmark-commit.yml
    M .github/workflows/libcxx-build-and-test.yaml
    M .github/workflows/libcxx-build-containers.yml
    M .github/workflows/libcxx-check-generated-files.yml
    M .github/workflows/libcxx-pr-benchmark.yml
    M .github/workflows/lldb-pylint-action.yml
    M .github/workflows/llvm-abi-tests.yml
    M .github/workflows/llvm-bugs.yml
    M .github/workflows/merged-prs.yml
    M .github/workflows/mlir-spirv-tests.yml
    M .github/workflows/new-issues.yml
    M .github/workflows/new-prs.yml
    M .github/workflows/pr-code-format.yml
    M .github/workflows/pr-code-lint.yml
    M .github/workflows/premerge.yaml
    M .github/workflows/prune-branches.yml
    M .github/workflows/release-asset-audit.yml
    M .github/workflows/release-binaries.yml
    M .github/workflows/release-documentation.yml
    M .github/workflows/release-doxygen.yml
    M .github/workflows/release-llvm-testing-tools.yml
    M .github/workflows/release-sources.yml
    M .github/workflows/release-tasks.yml
    M .github/workflows/require-team-membership/action.yml
    M .github/workflows/scorecard.yml
    M .github/workflows/spirv-tests.yml
    M .github/workflows/subscriber.yml
    M .github/workflows/sycl-tests.yml
    M .github/workflows/test-suite.yml
    M .github/workflows/test-unprivileged-download-artifact.yml
    M .github/workflows/upload-release-artifact/action.yml
    M .github/workflows/version-check.yml
    M .github/workflows/zizmor.yml
    M .mailmap
    M clang/docs/OpenMPSupport.md
    M clang/docs/ReleaseNotes.md
    A clang/docs/ScalableStaticAnalysis/user-docs/SourceEditGeneration.rst
    M clang/include/clang/AST/OpenMPClause.h
    M clang/include/clang/AST/RecursiveASTVisitor.h
    M clang/include/clang/Basic/DiagnosticFrontendKinds.td
    M clang/include/clang/Basic/DiagnosticIDs.h
    M clang/include/clang/Basic/DiagnosticSemaKinds.td
    M clang/include/clang/Basic/OpenMPKinds.def
    M clang/include/clang/Basic/OpenMPKinds.h
    M clang/include/clang/CIR/Dialect/Builder/CIRBaseBuilder.h
    M clang/include/clang/CIR/Dialect/IR/CIROps.td
    M clang/include/clang/CIR/Dialect/IR/CIRTypes.h
    M clang/include/clang/CIR/Dialect/Passes.h
    M clang/include/clang/CIR/Dialect/Passes.td
    M clang/include/clang/CIR/Interfaces/CIRLoopOpInterface.td
    M clang/include/clang/Frontend/SSAFOptions.h
    M clang/include/clang/Options/Options.td
    M clang/include/clang/ScalableStaticAnalysis/BuiltinAnchorSources.def
    A clang/include/clang/ScalableStaticAnalysis/Frontend/SourceTransformationFrontendAction.h
    M clang/include/clang/Sema/SemaOpenMP.h
    M clang/lib/AST/OpenMPClause.cpp
    M clang/lib/AST/StmtProfile.cpp
    M clang/lib/Basic/OpenMPKinds.cpp
    M clang/lib/Basic/Targets/X86.cpp
    M clang/lib/CIR/CodeGen/CIRGenBuiltin.cpp
    M clang/lib/CIR/CodeGen/CIRGenBuiltinAMDGPU.cpp
    M clang/lib/CIR/CodeGen/CIRGenBuiltinX86.cpp
    M clang/lib/CIR/CodeGen/CIRGenExpr.cpp
    M clang/lib/CIR/CodeGen/CIRGenExprAggregate.cpp
    M clang/lib/CIR/Dialect/IR/CIRDialect.cpp
    M clang/lib/CIR/Dialect/IR/CIRTypes.cpp
    M clang/lib/CIR/Dialect/Transforms/CMakeLists.txt
    M clang/lib/CIR/Dialect/Transforms/CallConvLoweringPass.cpp
    M clang/lib/CIR/Dialect/Transforms/PassDetail.h
    M clang/lib/CIR/Interfaces/CIRLoopOpInterface.cpp
    M clang/lib/CodeGen/CodeGenModule.cpp
    M clang/lib/CodeGen/CodeGenModule.h
    M clang/lib/CodeGen/TargetInfo.cpp
    M clang/lib/Driver/ToolChains/Clang.cpp
    M clang/lib/Driver/ToolChains/Hexagon.cpp
    M clang/lib/FrontendTool/ExecuteCompilerInvocation.cpp
    M clang/lib/Headers/riscv_packed_simd.h
    M clang/lib/Interpreter/Interpreter.cpp
    M clang/lib/Parse/ParseDecl.cpp
    M clang/lib/Parse/ParseOpenMP.cpp
    M clang/lib/ScalableStaticAnalysis/Analyses/CMakeLists.txt
    A clang/lib/ScalableStaticAnalysis/Analyses/SharedLexicalRepresentation/EntitySourceLocationExtractor.cpp
    M clang/lib/ScalableStaticAnalysis/Frontend/CMakeLists.txt
    A clang/lib/ScalableStaticAnalysis/Frontend/SourceTransformationFrontendAction.cpp
    M clang/lib/Sema/SemaDecl.cpp
    M clang/lib/Sema/SemaOpenMP.cpp
    M clang/lib/Sema/TreeTransform.h
    M clang/lib/Serialization/ASTReader.cpp
    M clang/lib/Serialization/ASTWriter.cpp
    M clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp
    M clang/lib/StaticAnalyzer/Checkers/WebKit/RawPtrRefCallArgsChecker.cpp
    M clang/test/Analysis/Checkers/WebKit/call-args.cpp
    M clang/test/Analysis/Scalable/help.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/Inputs/empty-suite.json
    A clang/test/Analysis/Scalable/source-edit-generation/Inputs/two-function-suite.json
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/CMakeLists.txt
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/TestTransformationPlugin/CMakeLists.txt
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/TestTransformationPlugin/TestTransformation.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/Plugins/lit.local.cfg
    A clang/test/Analysis/Scalable/source-edit-generation/cli-errors.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/coexistence.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/downgradable-errors.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/happy-path.cpp
    A clang/test/Analysis/Scalable/source-edit-generation/write-failure.cpp
    A clang/test/Analysis/std-c-library-functions-non-integral-ssize_t.cpp
    M clang/test/CIR/CodeGen/builtins-x86.c
    M clang/test/CIR/CodeGen/ternary-throw.cpp
    M clang/test/CIR/CodeGen/var_arg.c
    M clang/test/CIR/CodeGenBuiltins/X86/avx2-builtins.c
    M clang/test/CIR/CodeGenBuiltins/X86/avx512bw-builtins.c
    M clang/test/CIR/CodeGenBuiltins/X86/sse-builtins.c
    M clang/test/CIR/CodeGenBuiltins/builtins-elementwise.c
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-gfx1250.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn-vi-f16.hip
    M clang/test/CIR/CodeGenHIP/builtins-amdgcn.hip
    A clang/test/CIR/IR/invalid-loop-cleanup.cir
    A clang/test/CIR/IR/loop-cleanup.cir
    A clang/test/CIR/Transforms/abi-lowering/x86_64-lang-addrspace-nyi.cir
    A clang/test/CIR/Transforms/abi-lowering/x86_64-scalars.cir
    M clang/test/CMakeLists.txt
    A clang/test/CXX/dcl/dcl.spec/dcl.type/dcl.type.general/p2.cpp
    M clang/test/CodeGen/RISCV/rvp-intrinsics.c
    M clang/test/CodeGen/SystemZ/systemz-module.flags.c
    M clang/test/CodeGen/attr-target-mv.c
    M clang/test/CodeGen/attr-target-x86.c
    M clang/test/CodeGen/call-graph-section-callback.cpp
    M clang/test/CodeGen/call-graph-section-internal.cpp
    M clang/test/CodeGen/call-graph-section-templates.cpp
    M clang/test/CodeGen/call-graph-section-virtual-methods.cpp
    M clang/test/CodeGen/call-graph-section.c
    M clang/test/CodeGen/call-graph-section.cpp
    M clang/test/CodeGenHLSL/resources/TypedBuffers-constructor.hlsl
    M clang/test/CodeGenOpenCL/cl20-device-side-enqueue-attributes.cl
    M clang/test/Driver/hexagon-toolchain-linux.c
    A clang/test/OpenMP/dims_modifier_ast_print.cpp
    A clang/test/OpenMP/dims_modifier_messages.cpp
    M clang/test/OpenMP/ompx_bare_messages.c
    M clang/test/OpenMP/target_teams_distribute_num_teams_messages.cpp
    M clang/test/OpenMP/target_teams_distribute_parallel_for_num_teams_messages.cpp
    M clang/test/OpenMP/teams_num_teams_messages.cpp
    M clang/test/Parser/cxx1z-decomposition.cpp
    M clang/test/Sema/attr-target-mv.c
    M clang/test/Sema/attr-target.c
    M clang/tools/libclang/CIndex.cpp
    M clang/unittests/CIR/CMakeLists.txt
    M clang/unittests/CIR/ControlFlowTest.cpp
    A clang/unittests/CIR/GetFloatingPointTypeTest.cpp
    A clang/unittests/ScalableStaticAnalysis/Analyses/SharedLexicalRepresentation/EntitySourceLocationExtractorTest.cpp
    M clang/unittests/ScalableStaticAnalysis/CMakeLists.txt
    A compiler-rt/docs/ASanABI.md
    R compiler-rt/docs/ASanABI.rst
    A compiler-rt/docs/BuildingCompilerRT.md
    R compiler-rt/docs/BuildingCompilerRT.rst
    A compiler-rt/docs/TestingGuide.md
    R compiler-rt/docs/TestingGuide.rst
    M compiler-rt/test/profile/Linux/counter_promo_for.c
    M compiler-rt/test/profile/Linux/counter_promo_while.c
    M cross-project-tests/intrinsic-header-tests/riscv_packed_simd.c
    M flang/docs/CMakeLists.txt
    A flang/docs/CommandGuide/index.md
    R flang/docs/CommandGuide/index.rst
    M flang/include/flang/Optimizer/Dialect/FIROps.td
    M flang/include/flang/Optimizer/OpenACC/Support/FIROpenACCOpsInterfaces.h
    M flang/lib/Optimizer/CodeGen/CodeGen.cpp
    M flang/lib/Optimizer/Dialect/FIROps.cpp
    M flang/lib/Optimizer/OpenACC/Support/FIROpenACCOpsInterfaces.cpp
    M flang/lib/Optimizer/OpenACC/Support/RegisterOpenACCExtensions.cpp
    M flang/lib/Parser/openmp-parsers.cpp
    A flang/test/Fir/create-box-codegen.fir
    M flang/test/Fir/fir-ops.fir
    M flang/test/Fir/invalid.fir
    A flang/test/Transforms/OpenACC/acc-implicit-declare-type-descriptor-create-box.fir
    M libc/cmake/modules/LLVMLibCCompileOptionRules.cmake
    M libc/config/baremetal/aarch64/entrypoints.txt
    M libc/config/baremetal/arm/entrypoints.txt
    M libc/config/baremetal/riscv/entrypoints.txt
    M libc/config/darwin/aarch64/entrypoints.txt
    M libc/config/gpu/amdgpu/entrypoints.txt
    M libc/config/gpu/nvptx/entrypoints.txt
    M libc/config/linux/aarch64/entrypoints.txt
    M libc/config/linux/riscv/entrypoints.txt
    M libc/config/linux/x86_64/entrypoints.txt
    M libc/docs/headers/math/index.rst
    M libc/include/math.yaml
    M libc/shared/math.h
    A libc/shared/math/lgammaf16.h
    M libc/src/__support/File/linux/CMakeLists.txt
    M libc/src/__support/File/linux/dir.cpp
    M libc/src/__support/File/linux/file.cpp
    M libc/src/__support/OSUtil/linux/CMakeLists.txt
    M libc/src/__support/OSUtil/linux/auxv.h
    M libc/src/__support/math/CMakeLists.txt
    A libc/src/__support/math/lgammaf16.h
    M libc/src/__support/threads/linux/CMakeLists.txt
    M libc/src/__support/threads/linux/thread.cpp
    M libc/src/math/CMakeLists.txt
    M libc/src/math/generic/CMakeLists.txt
    A libc/src/math/generic/lgammaf16.cpp
    A libc/src/math/lgammaf16.h
    M libc/src/sched/linux/CMakeLists.txt
    M libc/src/sched/linux/sched_getaffinity.cpp
    M libc/src/semaphore/linux/CMakeLists.txt
    M libc/src/semaphore/linux/named_semaphore.cpp
    M libc/src/semaphore/linux/semaphore.h
    M libc/src/spawn/linux/CMakeLists.txt
    M libc/src/spawn/linux/posix_spawn.cpp
    M libc/src/stdio/linux/CMakeLists.txt
    M libc/src/stdio/linux/remove.cpp
    M libc/src/stdlib/linux/CMakeLists.txt
    M libc/src/stdlib/linux/realpath.cpp
    M libc/src/sys/ipc/linux/CMakeLists.txt
    M libc/src/sys/ipc/linux/ftok.cpp
    R libc/src/sys/ipc/linux/kernel_statx.h
    M libc/src/sys/mman/linux/CMakeLists.txt
    M libc/src/sys/mman/linux/shm_unlink.cpp
    M libc/src/sys/time/linux/CMakeLists.txt
    M libc/src/sys/time/linux/utimes.cpp
    M libc/startup/linux/x86_64/CMakeLists.txt
    M libc/startup/linux/x86_64/tls.cpp
    M libc/test/UnitTest/HermeticTestUtils.cpp
    M libc/test/shared/CMakeLists.txt
    M libc/test/shared/shared_math_test.cpp
    M libc/test/src/math/CMakeLists.txt
    A libc/test/src/math/lgammaf16_test.cpp
    M libc/test/src/math/smoke/CMakeLists.txt
    A libc/test/src/math/smoke/lgammaf16_test.cpp
    M libc/test/src/semaphore/linux/CMakeLists.txt
    M libc/test/src/semaphore/linux/semaphore_test.cpp
    M libc/test/src/stdlib/CMakeLists.txt
    M libc/test/src/stdlib/realpath_test.cpp
    M libc/utils/MPFRWrapper/MPCommon.cpp
    M libc/utils/MPFRWrapper/MPCommon.h
    M libc/utils/MPFRWrapper/MPFRUtils.cpp
    M libc/utils/MPFRWrapper/MPFRUtils.h
    M libcxx/src/support/runtime/exception_pointer_msvc.ipp
    M libcxx/test/libcxx/ranges/range.adaptors/range.enumerate/nodiscard.verify.cpp
    M libcxx/utils/ci/images/libcxx_release_runners.txt
    A libsycl/docs/CodingGuidelines.md
    R libsycl/docs/CodingGuidelines.rst
    A libsycl/docs/index.md
    R libsycl/docs/index.rst
    M libsycl/test/README.md
    A libunwind/docs/BuildingLibunwind.md
    R libunwind/docs/BuildingLibunwind.rst
    M libunwind/docs/conf.py
    A libunwind/docs/index.md
    R libunwind/docs/index.rst
    M lld/ELF/InputSection.cpp
    M lld/ELF/Relocations.h
    M lldb/bindings/interfaces.swig
    M lldb/docs/use/variable.md
    M lldb/include/lldb/API/LLDB.h
    M lldb/include/lldb/API/SBDefines.h
    A lldb/include/lldb/API/SBProtocolServer.h
    M lldb/include/lldb/API/SBValue.h
    M lldb/include/lldb/Core/Diagnostics.h
    M lldb/include/lldb/Core/PluginManager.h
    M lldb/include/lldb/DataFormatters/TypeSynthetic.h
    M lldb/include/lldb/Interpreter/ScriptInterpreter.h
    M lldb/include/lldb/ValueObject/ValueObject.h
    M lldb/include/lldb/ValueObject/ValueObjectSynthetic.h
    M lldb/packages/Python/lldbsuite/test/tools/lldb-dap/dap_server.py
    M lldb/source/API/CMakeLists.txt
    A lldb/source/API/SBProtocolServer.cpp
    M lldb/source/API/SBValue.cpp
    M lldb/source/Commands/CommandObjectScripting.cpp
    M lldb/source/Commands/Options.td
    M lldb/source/Core/CoreProperties.td
    M lldb/source/Core/Debugger.cpp
    M lldb/source/Core/Diagnostics.cpp
    M lldb/source/Core/PluginManager.cpp
    M lldb/source/DataFormatters/TypeSynthetic.cpp
    M lldb/source/Expression/IRInterpreter.cpp
    M lldb/source/Interpreter/ScriptInterpreter.cpp
    M lldb/source/Interpreter/embedded_interpreter.py
    M lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
    M lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.h
    M lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ScriptedPythonInterface.h
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPython.cpp
    M lldb/source/Plugins/ScriptInterpreter/Python/ScriptInterpreterPython.h
    M lldb/source/Plugins/SymbolFile/NativePDB/UdtRecordCompleter.cpp
    M lldb/source/Plugins/TraceExporter/common/TraceHTR.h
    A lldb/source/Plugins/TraceExporter/docs/htr.md
    R lldb/source/Plugins/TraceExporter/docs/htr.rst
    M lldb/source/ValueObject/ValueObject.cpp
    M lldb/source/ValueObject/ValueObjectSynthetic.cpp
    A lldb/test/API/functionalities/scripting_extension_generate/Makefile
    A lldb/test/API/functionalities/scripting_extension_generate/TestScriptingExtensionGenerate.py
    A lldb/test/API/functionalities/scripting_extension_generate/main.c
    A lldb/test/API/lang/cpp/enum-limits/Makefile
    A lldb/test/API/lang/cpp/enum-limits/TestCPPEnumLimits.py
    A lldb/test/API/lang/cpp/enum-limits/main.cpp
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/Makefile
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/TestSBValueSetTypeSynthetic.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/library_support.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic/main.cpp
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/Makefile
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/TestSBValueSetTypeSyntheticOverride.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/foo_bar_synths.py
    A lldb/test/API/python_api/sbvalue_set_type_synthetic_override/main.cpp
    A lldb/test/Shell/Diagnostics/TestDiagnosticsCollectBinaries.test
    M lldb/unittests/API/CMakeLists.txt
    A lldb/unittests/API/SBProtocolServerTest.cpp
    M lldb/unittests/Core/CMakeLists.txt
    A lldb/unittests/Core/DiagnosticsTest.cpp
    M lldb/unittests/Process/gdb-remote/CMakeLists.txt
    A lldb/unittests/Process/gdb-remote/ProcessGDBRemoteTest.cpp
    A llvm-libgcc/docs/LLVMLibgcc.md
    R llvm-libgcc/docs/LLVMLibgcc.rst
    M llvm-libgcc/generate_version_script.py
    A llvm/docs/AArch64SME.md
    R llvm/docs/AArch64SME.rst
    A llvm/docs/AMDGPUAsyncOperations.md
    R llvm/docs/AMDGPUAsyncOperations.rst
    A llvm/docs/AMDGPUExecutionSynchronization.md
    R llvm/docs/AMDGPUExecutionSynchronization.rst
    A llvm/docs/AMDGPUMemoryModel.md
    R llvm/docs/AMDGPUMemoryModel.rst
    A llvm/docs/AddingConstrainedIntrinsics.md
    R llvm/docs/AddingConstrainedIntrinsics.rst
    A llvm/docs/AdminTasks.md
    R llvm/docs/AdminTasks.rst
    A llvm/docs/BigEndianNEON.md
    R llvm/docs/BigEndianNEON.rst
    A llvm/docs/CompileCudaWithLLVM.md
    R llvm/docs/CompileCudaWithLLVM.rst
    A llvm/docs/DebuggingJITedCode.md
    R llvm/docs/DebuggingJITedCode.rst
    A llvm/docs/ExtendingLLVM.md
    R llvm/docs/ExtendingLLVM.rst
    A llvm/docs/HowToBuildWindowsItaniumPrograms.md
    R llvm/docs/HowToBuildWindowsItaniumPrograms.rst
    A llvm/docs/HowToCrossCompileBuiltinsOnArm.md
    R llvm/docs/HowToCrossCompileBuiltinsOnArm.rst
    A llvm/docs/HowToUpdateDebugInfo.md
    R llvm/docs/HowToUpdateDebugInfo.rst
    A llvm/docs/Instrumentor.md
    R llvm/docs/Instrumentor.rst
    A llvm/docs/JITLink.md
    R llvm/docs/JITLink.rst
    M llvm/docs/LangRef.md
    A llvm/docs/MCJITDesignAndImplementation.md
    R llvm/docs/MCJITDesignAndImplementation.rst
    A llvm/docs/NVPTXUsage.md
    R llvm/docs/NVPTXUsage.rst
    A llvm/docs/ORCv2.md
    R llvm/docs/ORCv2.rst
    A llvm/docs/Remarks.md
    R llvm/docs/Remarks.rst
    A llvm/docs/SPIRVUsage.md
    R llvm/docs/SPIRVUsage.rst
    M llvm/include/llvm/ADT/Eytzinger.h
    M llvm/include/llvm/ADT/GenericCycleImpl.h
    M llvm/include/llvm/ADT/GenericCycleInfo.h
    M llvm/include/llvm/ADT/GenericUniformityImpl.h
    M llvm/include/llvm/ADT/Sequence.h
    M llvm/include/llvm/Frontend/OpenMP/OMP.h
    M llvm/include/llvm/IR/Function.h
    M llvm/include/llvm/IR/PassManagerInternal.h
    M llvm/include/llvm/MC/MCSchedule.h
    M llvm/include/llvm/ProfileData/SampleProf.h
    M llvm/include/llvm/ProfileData/SampleProfReader.h
    M llvm/include/llvm/ProfileData/SampleProfWriter.h
    M llvm/include/llvm/Support/MathExtras.h
    M llvm/include/llvm/TargetParser/X86TargetParser.def
    M llvm/lib/Analysis/AliasAnalysis.cpp
    M llvm/lib/Analysis/ScalarEvolution.cpp
    M llvm/lib/CodeGen/AsmPrinter/AsmPrinter.cpp
    M llvm/lib/CodeGen/MachineFunction.cpp
    M llvm/lib/CodeGen/SelectionDAG/DAGCombiner.cpp
    M llvm/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
    M llvm/lib/DWARFLinker/Parallel/SyntheticTypeNameBuilder.cpp
    M llvm/lib/Frontend/OpenMP/OMP.cpp
    M llvm/lib/IR/Verifier.cpp
    M llvm/lib/ProfileData/SampleProfReader.cpp
    M llvm/lib/ProfileData/SampleProfWriter.cpp
    M llvm/lib/Support/Unix/Signals.inc
    M llvm/lib/Target/AArch64/AArch64AsmPrinter.cpp
    M llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
    M llvm/lib/Target/AArch64/AArch64InstrInfo.td
    M llvm/lib/Target/AArch64/MCTargetDesc/AArch64MCLFIRewriter.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUISelLowering.cpp
    M llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.cpp
    M llvm/lib/Target/AMDGPU/SOPInstructions.td
    M llvm/lib/Target/DirectX/DXContainerGlobals.cpp
    M llvm/lib/Target/DirectX/DXILWriter/DXILWriterPass.cpp
    M llvm/lib/Target/NVPTX/NVPTXISelLowering.cpp
    M llvm/lib/Target/SPIRV/SPIRVInstructionSelector.cpp
    M llvm/lib/Target/WebAssembly/WebAssembly.h
    M llvm/lib/Target/WebAssembly/WebAssemblyCodeGenPassBuilder.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyLateEHPrepare.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyPassRegistry.def
    M llvm/lib/Target/WebAssembly/WebAssemblyReplacePhysRegs.cpp
    M llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp
    M llvm/lib/Target/X86/X86FlagsCopyLowering.cpp
    M llvm/lib/Target/X86/X86ISelLowering.cpp
    M llvm/lib/Target/X86/X86InstrInfo.cpp
    M llvm/lib/Target/X86/X86InstrInfo.h
    M llvm/lib/Target/X86/X86InstrTBM.td
    M llvm/lib/Transforms/InstCombine/InstCombineCalls.cpp
    M llvm/lib/Transforms/InstCombine/InstCombineCasts.cpp
    M llvm/lib/Transforms/InstCombine/InstCombineSimplifyDemanded.cpp
    M llvm/lib/Transforms/Scalar/ConstraintElimination.cpp
    M llvm/lib/Transforms/Scalar/TailRecursionElimination.cpp
    M llvm/lib/Transforms/Utils/SSAUpdater.cpp
    M llvm/lib/Transforms/Vectorize/CMakeLists.txt
    M llvm/lib/Transforms/Vectorize/LoopVectorizationPlanner.h
    M llvm/lib/Transforms/Vectorize/LoopVectorize.cpp
    M llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
    M llvm/lib/Transforms/Vectorize/VPlan.h
    A llvm/lib/Transforms/Vectorize/VPlanEVLTailFolding.cpp
    M llvm/lib/Transforms/Vectorize/VPlanRecipes.cpp
    M llvm/lib/Transforms/Vectorize/VPlanTransforms.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUnroll.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.cpp
    M llvm/lib/Transforms/Vectorize/VPlanUtils.h
    M llvm/test/Analysis/BasicAA/atomics.ll
    A llvm/test/Analysis/LoopAccessAnalysis/non-affine-monotonic-bounds.ll
    M llvm/test/Analysis/ScalarEvolution/max-backedge-taken-count-guard-info.ll
    M llvm/test/CodeGen/AArch64/is_fpclass.ll
    M llvm/test/CodeGen/AArch64/ptrauth-intrinsic-auth-resign-with-blend.ll
    M llvm/test/CodeGen/AArch64/sms-loop-carried-fp-exceptions1.mir
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-gather.ll
    M llvm/test/CodeGen/AArch64/sve-fixed-length-masked-scatter.ll
    M llvm/test/CodeGen/AArch64/sve-streaming-mode-cvt-fp-to-int.ll
    M llvm/test/CodeGen/AArch64/sve-streaming-mode-cvt-int-to-fp.ll
    M llvm/test/CodeGen/AMDGPU/div-rem-fast-path.ll
    M llvm/test/CodeGen/AMDGPU/med3-knownbits.ll
    M llvm/test/CodeGen/AMDGPU/print-pipeline-passes.ll
    M llvm/test/CodeGen/AMDGPU/sdiv.ll
    M llvm/test/CodeGen/AMDGPU/udiv.ll
    M llvm/test/CodeGen/ARM/call-graph-section-addrtaken.ll
    M llvm/test/CodeGen/ARM/call-graph-section-assembly.ll
    M llvm/test/CodeGen/ARM/call-graph-section-tailcall.ll
    M llvm/test/CodeGen/ARM/call-graph-section.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-allow-ftz-atomics.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-sm60.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-sm70.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw-sm90.ll
    M llvm/test/CodeGen/NVPTX/atomicrmw.py
    M llvm/test/CodeGen/NVPTX/atomics.ll
    M llvm/test/CodeGen/PowerPC/milicode32.ll
    M llvm/test/CodeGen/PowerPC/ppcf128-constrained-fp-intrinsics.ll
    M llvm/test/CodeGen/RISCV/double-intrinsics-strict.ll
    M llvm/test/CodeGen/RISCV/float-intrinsics-strict.ll
    A llvm/test/CodeGen/RISCV/rvv/vecreduce-minmax-constant-fold.ll
    M llvm/test/CodeGen/RISCV/zfh-half-intrinsics-strict.ll
    M llvm/test/CodeGen/RISCV/zfhmin-half-intrinsics-strict.ll
    M llvm/test/CodeGen/SPIRV/extensions/SPV_KHR_bfloat16/bfloat16.ll
    M llvm/test/CodeGen/SPIRV/llvm-intrinsics/constrained-fmuladd.ll
    M llvm/test/CodeGen/X86/apx/add.ll
    M llvm/test/CodeGen/X86/apx/flags-copy-lowering.ll
    A llvm/test/CodeGen/X86/apx/optimize-compare-multipred.ll
    A llvm/test/CodeGen/X86/apx/optimize-compare-multipred.mir
    M llvm/test/CodeGen/X86/apx/sub.ll
    M llvm/test/CodeGen/X86/call-graph-section-addrtaken.ll
    M llvm/test/CodeGen/X86/call-graph-section-assembly.ll
    M llvm/test/CodeGen/X86/call-graph-section-tailcall.ll
    M llvm/test/CodeGen/X86/call-graph-section.ll
    A llvm/test/CodeGen/X86/dagcombine-sub-globaladdress.ll
    M llvm/test/CodeGen/X86/tbm_patterns.ll
    A llvm/test/MC/AArch64/LFI/debug-info.s
    M llvm/test/TableGen/CompressWriteLatencyEntry.td
    A llvm/test/TableGen/RuntimeLibcallEmitter-predicate-cc-sort.td
    A llvm/test/TableGen/subreg-index-overflow-allowed.td
    A llvm/test/TableGen/subreg-index-overflow.td
    M llvm/test/Transforms/ConstraintElimination/constraint-overflow.ll
    M llvm/test/Transforms/EarlyCSE/replace-calls-def-attrs.ll
    M llvm/test/Transforms/IndVarSimplify/drop-exact.ll
    M llvm/test/Transforms/IndVarSimplify/pr66066.ll
    M llvm/test/Transforms/IndVarSimplify/strengthen-overflow.ll
    M llvm/test/Transforms/InstCombine/erf.ll
    M llvm/test/Transforms/InstCombine/fdim.ll
    M llvm/test/Transforms/InstCombine/fsh.ll
    M llvm/test/Transforms/InstCombine/simplify-demanded-fpclass-fdiv.ll
    M llvm/test/Transforms/InstCombine/trunc.ll
    M llvm/test/Transforms/InstSimplify/disable_folding.ll
    A llvm/test/Transforms/LoopVectorize/AArch64/non-affine-monotonic-bounds.ll
    M llvm/test/Transforms/LoopVectorize/VPlan/RISCV/expand-scev.ll
    M llvm/test/Transforms/LoopVectorize/VPlan/dissolve-replicate-regions.ll
    A llvm/test/Transforms/LoopVectorize/non-affine-monotonic-bounds.ll
    M llvm/test/Transforms/LoopVectorize/single-early-exit-deref-assumptions.ll
    M llvm/test/Transforms/PhaseOrdering/AMDGPU/infer-address-space.ll
    A llvm/test/Transforms/SLPVectorizer/AArch64/masked-div-rem-non-pow2-revec.ll
    A llvm/test/Transforms/SLPVectorizer/AArch64/masked-div-rem-non-pow2.ll
    M llvm/test/Transforms/SLPVectorizer/X86/debug-info-salvage.ll
    M llvm/test/Transforms/SLPVectorizer/X86/minmax-main-opcode-copyables-cost.ll
    M llvm/test/Transforms/SLPVectorizer/X86/minmax-main-opcode-copyables.ll
    M llvm/test/Transforms/SLPVectorizer/X86/split-node-num-operands.ll
    M llvm/test/Transforms/SLPVectorizer/splat-buildvector.ll
    A llvm/test/Transforms/SROA/sroa-self-referential-load.ll
    M llvm/test/Transforms/SimplifyCFG/X86/merge-compatible-invokes-of-landingpad.ll
    A llvm/test/Transforms/TailCallElim/disable-tail-call-elim-for-cold-calls.ll
    M llvm/test/Verifier/callee-type-metadata.ll
    M llvm/test/tools/llvm-profdata/profile-symbol-list.test
    M llvm/tools/llvm-libtool-darwin/llvm-libtool-darwin.cpp
    M llvm/unittests/ADT/EytzingerTest.cpp
    M llvm/unittests/ADT/SequenceTest.cpp
    M llvm/unittests/Frontend/OpenMPDirectiveNameParserTest.cpp
    M llvm/unittests/IR/PassManagerTest.cpp
    M llvm/unittests/IR/VerifierTest.cpp
    M llvm/unittests/ProfileData/SampleProfTest.cpp
    M llvm/unittests/Support/MathExtrasTest.cpp
    M llvm/utils/TableGen/Basic/RuntimeLibcallsEmitter.cpp
    M llvm/utils/TableGen/Common/CodeGenRegisters.cpp
    M llvm/utils/TableGen/Common/CodeGenRegisters.h
    M llvm/utils/TableGen/SubtargetEmitter.cpp
    M llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/Analyses/BUILD.gn
    M llvm/utils/gn/secondary/clang/lib/ScalableStaticAnalysis/Frontend/BUILD.gn
    M llvm/utils/gn/secondary/clang/unittests/CIR/BUILD.gn
    M llvm/utils/gn/secondary/clang/unittests/ScalableStaticAnalysis/BUILD.gn
    M llvm/utils/gn/secondary/lldb/source/API/BUILD.gn
    M llvm/utils/gn/secondary/llvm/lib/Transforms/Vectorize/BUILD.gn
    M mlir/include/mlir/Dialect/OpenACC/OpenACCCGOps.td
    M mlir/include/mlir/Dialect/OpenACC/OpenACCOpsInterfaces.td
    M mlir/include/mlir/IR/CMakeLists.txt
    M mlir/include/mlir/IR/SymbolInterfaces.td
    M mlir/include/mlir/IR/SymbolTable.h
    M mlir/lib/Dialect/Bufferization/IR/BufferizationOps.cpp
    M mlir/lib/Dialect/Bufferization/Transforms/BufferDeallocationSimplification.cpp
    M mlir/lib/Dialect/OpenACC/IR/OpenACC.cpp
    M mlir/lib/Dialect/OpenACC/Transforms/ACCImplicitDeclare.cpp
    M mlir/lib/Dialect/OpenACC/Transforms/ACCRecipeMaterialization.cpp
    M mlir/lib/IR/SymbolTable.cpp
    M mlir/lib/Interfaces/ValueBoundsOpInterface.cpp
    M mlir/lib/Target/Wasm/TranslateFromWasm.cpp
    M mlir/test/Dialect/Bufferization/Transforms/buffer-deallocation-simplification.mlir
    M mlir/test/Dialect/Bufferization/canonicalize.mlir
    M mlir/test/Dialect/OpenACC/acc-implicit-declare.mlir
    M mlir/test/Dialect/OpenACC/ops-cg.mlir
    A mlir/test/IR/test-verifiers-symbol-user-type.mlir
    M mlir/test/Target/LLVMIR/llvmir-intrinsics.mlir
    M mlir/test/lib/Dialect/Test/TestTypeDefs.td
    M mlir/test/lib/Dialect/Test/TestTypes.cpp
    M mlir/test/lib/Dialect/Test/TestTypes.h
    M offload/docs/conf.py
    A offload/docs/index.md
    R offload/docs/index.rst
    M openmp/runtime/src/kmp_i18n.cpp
    M orc-rt/docs/Design.md
    M orc-rt/include/orc-rt/QueueingRunner.h
    M orc-rt/include/orc-rt/Session.h
    M orc-rt/lib/executor/Session.cpp
    M orc-rt/test/unit/CommonTestUtils.h
    M orc-rt/test/unit/InProcessControllerAccessTest.cpp
    M orc-rt/test/unit/QueueingRunnerTest.cpp
    M orc-rt/test/unit/SessionTest.cpp
    M polly/include/polly/DependenceInfo.h
    M polly/lib/Analysis/DependenceInfo.cpp
    M polly/lib/CodeGen/IslAst.cpp
    A polly/test/IstAstInfo/AstGenComputeOut.ll
    M utils/bazel/llvm-project-overlay/clang/BUILD.bazel
    M utils/bazel/llvm-project-overlay/libc/BUILD.bazel
    M utils/bazel/llvm-project-overlay/libc/test/src/sys/socket/BUILD.bazel
    M utils/bazel/llvm-project-overlay/lldb/source/Plugins/BUILD.bazel
    M utils/bazel/llvm-project-overlay/lldb/source/Plugins/plugin_config.bzl
    M utils/bazel/llvm-project-overlay/mlir/BUILD.bazel

  Log Message:
  -----------
  Merge branch 'main' into users/tonykuttai/bump-diag-size-frontend


Compare: https://github.com/llvm/llvm-project/compare/e9473e1e878b...126d90ac9593

To unsubscribe from these emails, change your notification settings at https://github.com/llvm/llvm-project/settings/notifications


More information about the All-commits mailing list